function display(objeps)
% DISPLAY display properties of an epsilon_mRPI object in the command window
% 
% objeps.display
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Display properties of an epsilon_mRPI object in the command window
%
% USAGE:
% 
% objeps.display
% objeps
%
% see also EPSILON_MRPI
 

%Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------  

 
    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if numel(objeps)==0
        fprintf('Empty epsilon- minimal Robust Positively Invariant.\n');
        return;
    elseif numel(objeps) > 1
        fprintf('Array of %i minimal Robust Positively Invariant\n', numel(objeps));
        return
    end
    
    if isempty(objeps.A)
        fprintf('Empty minimal Robust Positively Invariant.\n');
        return;
    end
    
    fprintf('%f-approximation of the minimal Robust Positively Invariant (mRPI) in R^%d\n',objeps.epsilon,size(objeps.A,1));
    fprintf('\t Methods:\n');
    if isa(objeps.W,'zonotope')
        fprintf('\t\t .doublePG mRPI as zonotope\n');
    else
        fprintf('\t\t .doubleHK mRPI as Polyhedron\n');
    end
    fprintf('\t\t .isinside check if x is in mRPI\n');
    fprintf('\t\t .plot plot mRPI\n');
    
end