function [ p G F ] = doublePG(obj)
% DOUBLEPG Returns the generators representation of an epsilon-mRPI object when it is a zonotope
%
% [ p G F ] = doublePG(obj)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% The generators representation of a zonotope F is 
% F = { x | x=p+Gd , ||d||_inf<=1 }
%
% USAGE:
%
% [ p G F ] = obj.doublePG
%   F       = obj.doublePG
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% epsilon_mRPI object
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% Matrices p and G
% F updated epsilon_mRPI object with F_epsilon field as a zonotope object
%
%
% see also EPSILON_MRPI ZONOTOPE

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
% (C) 2012 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ~isa(obj.W,'zonotope')
        error('DOUBLEPG: W is a Polyhedron, the method does not convert the set in a zonotope set')
    end
    
    if isempty(obj.F_epsilonZ)
        Z = zonotope(obj.vertMink.p,obj.vertMink.G);
        p = Z.p;
        G = Z.G;
        F = obj;
        F.F_epsilonZ = Z;
        if nargout==1
            p = F;
        end
    else
        F = obj;
        if nargout==1
            p = F;
            return
        end
        p = F.F_epsilonZ.p;
        G = F.F_epsilonZ.G;
    end
    
end