function plot(obj,dimx)
% PLOT Plots an epsilon-mRPI set epsilon approximation of the minimal robust positively invariant set
%
% plot(obj,dimx)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% If the object of class epsilon-mRPI is a set of more then 3 dimensions,
% only the firsts 3 dimensions are plotted. Otherwise with dimx one can
% select the dimensions to plot.
% 
% USAGE: 
%  
% obj.PLOT
% obj.PLOT(dimx)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% dimx = dimensions to plot (optional)
%  
%
% see also EPSILON_MRPI

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
% (C) 2012 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin==2
        if isempty(dimx)
            dimx = 1:min([size(obj.A,1),3]);
        else
            if any(dimx>size(obj.A,2))
                error('PLOT: number of state variables')
            end
        end
    elseif nargin==1
        dimx = 1:min([size(obj.A,1),3]);
    else
        error('PLOT: number of parameters')
    end
    
    title('Epsilon approximation of the minimal robust positively invariant set')
    hold on
    if ~isa(obj.W,'zonotope')
        if length(dimx)>1
            lambda = sdpvar(obj.s,size(obj.vertMink.V,2));
            x      = sdpvar(size(obj.A,1),1);
            xV     = reshape(obj.vertMink.V,size(obj.A,1),[]);
            plot( [ lambda(:)>=0 ; sum(lambda,2)==1 ; x == sum(repmat(reshape(lambda',1,[]),size(obj.A,1),1).*xV,2) ] , x(dimx) , 'r' );
        else
            sumMax = 0;
            sumMin = 0;
            for i=1:obj.s
                sumMax = sumMax + max(obj.vertMink.V(dimx,:,i)) ;
                sumMin = sumMin + min(obj.vertMink.V(dimx,:,i)) ;
            end
            plot([sumMin,sumMax],zeros(1,2),'LineWidth',4,'Color','r')
        end
    else
        x = sdpvar(size(obj.A,1),1);
        d = sdpvar(size(obj.vertMink.G,2),1);
        plot([x==obj.vertMink.p+obj.vertMink.G*d;norm(d,inf)<=1],x(dimx),'r');
    end
    
    if length(dimx)>=1
        xlabel(['x_{' num2str(dimx(1)) '}'],'FontSize',16,'FontName','Arial');
    end
    if length(dimx)>=2
        ylabel(['x_{' num2str(dimx(2)) '}'],'FontSize',16,'FontName','Arial');
    end
    if length(dimx)==3
        zlabel(['x_{' num2str(dimx(3)) '}'],'FontSize',16,'FontName','Arial');
    end
    hold off
end