function display(est)
% DISPLAY display properties of an lse object in the command window
% 
% est.display
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Display properties of an lse object in the command window
%
% USAGE:
% 
% est.display
% est
%
% see also LSE
 

%Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------  

    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if numel(est)==0
        fprintf('Empty large-scale estimator.\n');
        return;
    elseif numel(est) > 1
        fprintf('Array of %i large-scale estimators\n', numel(est));
        return
    end
    
    if isempty(est.A)
        fprintf('Empty large-scale estimator.\n');
        return;
    end
    
    fprintf('Large-scale estimator for %d subsystems\n',numel(est.ni));
    
    fprintf('\tInputs:\n');
    fprintf('\t\t %d state estimates\n',sum(est.ni));
    fprintf('\t\t %d outputs\n',sum(est.pi));
    fprintf('\t\t %d local control inputs\n',sum(est.mi));
    
    if ~isempty(est.ICen)
        fprintf('\t\t %d centralized control input (see .ICen)\n',numel(est.ICen));
    end
    if ~isempty(est.Exo)
        fprintf('\t\t %d exogenous inputs (see .Exo)\n',numel(est.Exo));
    end
    
    
    fprintf('\tOutputs:\n');
    fprintf('\t\t %d state estimates\n',sum(est.ni));
    fprintf('\t\t %d output estimates\n',sum(est.pi));
    
    if ~isempty(est.ExoBounded)
        fprintf('\tRobustness:\n');
    end
    fprintf('\t\t bounded-error estimation\n');
    if ~isempty(est.ExoBounded)
        fprintf('\t\t %d exogenous inputs (see .ExoBounded)\n',numel(est.ExoBounded));
    end
    
    tmp = full(est.Delta~=diag(true(numel(est.ni),1)));
    if any(any(tmp))
        fprintf('\t\t %d subsystems send their outputs to child subsystems\n',numel(sum(tmp,2)~=0));
    end
    
    
end