function B = getB(obj,i)
% GETB get matrix B
% 
% B = getB(obj,i)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall matrix B or the matrix Bi.
% 
% USAGE:
%
% B : getB(obj) return the overall matrix B
% B : getB(obj,i) return the local matrix Bi
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj : lse object
%
% i : index of the subsystem
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% B : matrix B
%
%
% see also LSE

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
% (C) 2012 
%     Daria Rubini, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     daria.rubini01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin<1 || nargin>2
        error('GETB: number of input parameters')
    end
    
    if nargin>1 && (~isa(i,'double'))
        error('GETB: indeces of systems')
    end
    
    if nargin>1 && (i<1 || i>length(obj.ni))
        error('GETB: i must be positive and less than %d',length(obj.ni))
    end
    
    if nargin==1
        B = obj.B;
        return
    end
    
    if nargin==2
        outi = sum(obj.pi(1:i-1))+1:sum(obj.pi(1:i));
        ini  = sum(obj.pi) + (sum(obj.mi(1:i-1))+1:sum(obj.mi(1:i)));
        jj   = setdiff(find(obj.Delta(i,:)==1),i);
        outj = [];
        for j=jj
            outj = [ outj sum(obj.pi(1:j-1))+1:sum(obj.pi(1:j)) ]; %#ok<AGROW>
        end
        ducen = (sum(obj.pi)+sum(obj.mi)+1):size(obj.B,2) ;
        B    = obj.B(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),[outi,outj,ini]);
        
        Aij = [];
        for j=setdiff(find(obj.couplingmatrix(i,:)==1),i)
            Aij = [ Aij obj.getA(i,j) ]; %#ok<AGROW>
        end
        
        B = [ B Aij obj.B(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),ducen) ];
    end
    
end