function Delta = getDelta(obj,i,j)
% GETDELTA return the Delta
% 
% Delta = getDelta(obj,i,j)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall Delta or the element ij of it.
% 
% USAGE:
%
% Delta = getDelta(obj)
% Delta = getDelta(obj,i,j)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj : lse object
%
% i : index of the first subsystem
% 
% j : index of the second subsystem
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% Delta : the Delta or the element ij of it.
% Consider element ij of Delta:
% false - means that subsystem j does not send outputs to subsystem i,
% true  - means that subsystem j does send outputs to subsystem i
%
% see also LSE

% Copyright is with the following author(s):
%
% (C) 2012 
%     Daria Rubini, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     daria.rubini01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    if nargin~=1 && nargin~=3
        error('GETDELTA: number of input parameters')
    end
    
    if nargin>1
        if ~isa(i,'double')
            error('GETDELTA: indeces of systems')
        end
        if i<1 || i>length(obj.ni)
            error('GETDELTA: i must be positive and less than %d',length(obj.ni))
        end
        if ~isa(j,'double')
            error('GETDELTA: indeces of systems')
        end
        if j<1 || j>length(obj.ni)
            error('GETDELTA: j must be positive and less than %d',length(obj.ni))
        end
    end
    
    if nargin==1
        Delta = obj.Delta;
    end
    
    if nargin>1
        Delta = obj.Delta(i,j);
    end
    
end