function [ T , alpha ] = getDynTheta(obj,i)
% GETDYNTHETA get vector alpha
% 
% [ T , alpha ] = getDynTheta(obj,i)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall vector alpha or the element i of alpha.
% 
% USAGE:
%
% [ T , alpha ] = getDynTheta(obj) return the overall contraction dynamics
% [ T , alpha ] = getDynTheta(obj,i) return the i-th element of the
%                 contraction dynamics
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj : lse object
%
% i : index of the subsystem
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% alpha = vector alpha or i-th element of alpha
% 
%
% see also LSE

% Copyright is with the following author(s):
%
% (C) 2012 
%     Daria Rubini, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     daria.rubini01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin<1 || nargin>2
        error('GETALPHA: number of input parameters')
    end
    
    if nargin>1 && (~isa(i,'double'))
        error('GETALPHA: indeces of systems')
    end
    
    if nargin>1 && (i<1 || i>length(obj.ni))
        error('GETALPHA: i must be positive and less than %d',length(obj.ni))
    end
    
    if nargin==1
        T     = obj.T;
        alpha = obj.alpha;
    end
    
    if nargin==2
        T     = obj.T(i,:);
        alpha = obj.alpha(i);
    end
    
end