function L = getL(obj,i,j)
% GETL get matrix L
% 
% L = getL(obj,i,j)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall matrix L or the matrix Lij.
% 
% USAGE:
%
% L = getL(obj) return the overall matrix L
% L = getL(obj,i) return the local matrix Lii
% L = getL(obj,i,j) return the local matrix Lij
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj : lse object
%
% i : index of the first subsystem
% 
% j : index of the second subsystem
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% L : matrix L
% 
%
% see also LSE

% Copyright is with the following author(s):
%
% (C) 2012 
%     Daria Rubini, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     daria.rubini01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin<1 || nargin>3
        error('GETL: number of input parameters')
    end
    
    if nargin>1
        if ~isa(i,'double')
            error('GETL: indeces of systems')
        end
        if i<1 || i>length(obj.ni)
            error('GETL: i must be positive and less than %d',length(obj.ni))
        end
        if nargin==3
            if ~isa(j,'double')
                error('GETL: indeces of systems')
            end
            if j<1 || j>length(obj.ni)
                error('GETL: j must be positive and less than %d',length(obj.ni))
            end
        end
    end
    
    if nargin==1
        L = obj.L;
    end
    
    if nargin==2
        j = i;
    end
    
    if nargin>1
        L = obj.L(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),sum(obj.pi(1:j-1))+1:sum(obj.pi(1:j)));
    end
    
end