function obj = addExoConstraint(obj,exoindex,H,K)
% ADDEXOCONSTRAINT defines polyhedral constraint on exogenous input
%
% objlss = ADDEXOCONSTRAINT(objlss,exoindex,H,K)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% H and K are such that H*d(exoindex)<=K
% 
% objlss = objlss.ADDEXOCONSTRAINT(exoindex,H,K)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% exoindex = index of the involved exogenous input for the constraint 
%
% H and K are such that H*d(exoindex)<=K
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the constraint saved in Hd and Kd
% 
%
% see also ADDEXOINPUT REMOVEEXOINPUT REMOVECONSTRAINT
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin~=4
        error('ADDEXOCONSTRAINT: number of input')
    end
    
    [ hr, hc ] = size(H);
    [ kr, kc ] = size(K);
    
    if hr~=kr
        error('ADDEXOCONSTRAINT: h rows=%d ~= k rows=%d',hr,kr)
    end
    
    if kc~=1
        error('ADDEXOCONSTRAINT: k col=%d ~= 1',kc)
    end
    
    if  ~isa(exoindex,'double')
        error('ADDEXOCONSTRAINT: indeces of systems');
    end
    
    if hc ~= length(exoindex)
        error('ADDEXOCONSTRAINT: H columns')
    end
    
    if isempty(obj.rd)
        obj.rd=zeros(1,obj.numExo);
    end
    
    if size(obj.rd,2)~=obj.numExo
        obj.rd(1,obj.numExo)=0;
    end
    
    Haux = zeros(hr,size(obj.M,2));
    vtmp = ones(length(exoindex),1)==1;
    for i = 1:length(exoindex)
        if exoindex(i)>obj.numExo
            error('ADDEXOCONSTRAINT: Exo number %d not yet inserted',exoindex(i))
        end
        Htmp = H(:,i);
        Haux(:,exoindex(i)) = Htmp;
        if all(all(Htmp==0))
            vtmp(i) = 0;
        end
    end
    
    if ~isscalar(exoindex) && sum(vtmp)==1
        exoindex = exoindex(vtmp);
        warning('ADDEXOCONSTRAINT: coupled constraints are reduced to local constraints for exogenous input %d',exoindex); %#ok<WNTAG>
    end
    
    if length(exoindex)==1
        obj.Hd           = sparse( [obj.Hd(1:sum(obj.rd(1:exoindex)),:) ; Haux ; obj.Hd(sum(obj.rd(1:exoindex))+1:end,:) ]);
        obj.Kd           = sparse( [obj.Kd(1:sum(obj.rd(1:exoindex)))   ; K    ; obj.Kd(sum(obj.rd(1:exoindex))+1:end)   ]);
        obj.rd(exoindex) = obj.rd(exoindex)+hr;
        return
    end
    
    obj.Hd = sparse([ obj.Hd ; Haux ]);
    obj.Kd = sparse([ obj.Kd ; K    ]);
    
end