function display(objlss)
% DISPLAY display properties of an lss object in the command window
% 
% objlss.display
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Display properties of an lss object in the command window
%
% USAGE:
% 
% objlss.display
% objlss
%
% see also LSS
 

%Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------      

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if numel(objlss)==0
        fprintf('Empty large-scale system.\n');
        return;
    elseif numel(objlss) > 1
        fprintf('Array of %i large-scale systems.\n', numel(objlss));
        return
    end
    
    if objlss.numSys==0
        fprintf('Empty large-scale system.\n');
        return;
    end
    
    fprintf('Large-scale system composed of %d subsystems\n',objlss.numSys);
    if objlss.Ts==-1
        fprintf('\tDiscrete-time LSS\n');
    elseif objlss.Ts>0
        fprintf('\tContinuous-time LSS, discretize with sample time: %f\n',objlss.Ts);
    else
        fprintf('\tContinuous-time LSS\n');
    end
    
    fprintf('\tVariables:\n');
    if isempty(objlss.pi)
        fprintf('\t\t%d states; state-feedback\n',sum(objlss.ni));
    else
        fprintf('\t\t%d states\n',sum(objlss.ni));
    end
    if sum(objlss.mi)~=0
        fprintf('\t\t%d local inputs\n',sum(objlss.mi));
    end
    if ~isempty(objlss.pi)
        fprintf('\t\t%d outputs\n',sum(objlss.pi));
    end
    if objlss.numICen~=0
        fprintf('\t\t%d centralized inputs\n',objlss.numICen);
    end
    if objlss.numExo~=0
        fprintf('\t\t%d exogenous inputs\n',objlss.numExo);
    end
    
    if sum(objlss.rx)~=0 || sum(objlss.ru)~=0 || sum(objlss.rdeltau)~=0 || sum(objlss.ry)~=0 || sum(objlss.rd)~=0 || sum(objlss.rcen)~=0 || sum(objlss.re)~=0
        fprintf('\tConstraints:\n');
        if ~isempty(objlss.Hx)
            fprintf('\t\t%d subsystems have state constraints\n',sum(objlss.rx~=0));
        end
        if ~isempty(objlss.Hu)
            fprintf('\t\t%d subsystems have input constraints\n',sum(objlss.ru~=0));
        end
        if ~isempty(objlss.Hdeltau)
            fprintf('\t\t%d subsystems have input rate constraints\n',sum(objlss.rdeltau~=0));
        end
        if ~isempty(objlss.pi)
            if ~isempty(objlss.Hy)
                fprintf('\t\t%d subsystems have output constraints\n',sum(objlss.ry~=0));
            end
        end
        if sum(objlss.rcen)~=0
            fprintf('\t\t%d centralized inputs have constraints\n',sum(objlss.rcen~=0));
        end
        if sum(objlss.rd)~=0
            fprintf('\t\t%d exogenous inputs have constraints\n',sum(objlss.rd~=0));
        end
        if ~isempty(objlss.He)
            fprintf('\t\t%d subsystems have error state estimation constraints\n',sum(objlss.re~=0));
        end
    end
    
    
end