function eigenvalues = eig(obj,i)
% EIG Computes the eigenvalues of a large-scale system
% 
% eigenvalues = EIG(obj)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the eigenvalues of the matrix A of the large-scale system
% 
% eigenvalues = objlss.eig
%
% USAGE:
% eigenvalues = objlss.eig(i) returns the eigenvalues of matrix Aii
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% - obj lss object
% - i index or name of the i-th subsystem (optional)
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% eigenvalues of the large-scale system or of the i-th subsystem
% 
%
% see also GETA

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin==1
        A = full(obj.getA);
    else
        if ~(isa(i,'double') || isa(i,'char'))
            error('EIG: the second argument must be integer or char')
        end
        if isa(i,'char')
            i = obj.name2index(i);
        end
        if i<=0 || i>obj.numSys
            error('EIG: the lss object has %d subsystems',obj.numSys)
        else
            A = full(obj.getA(i));
        end
    end
    
    eigenvalues = eig(A);
end