function A = getA(obj,i,j)   
% GETA gets the matrix A
% 
% A = objlss.getA(i,j)
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall matrix A or the matrix Aij.
% 
% A = objlss.GETA(i,j) return the dynamic coupling between system i and j
% 
% USAGE:
% A = objlss.getA() return the overall dynamic matrix A
%
% A = objlss.getA(i) return the local dynamic matrix Aii of system i
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the first system
% 
% j = number or name of the second system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% A desired dynamic matrix
% 
%
% see also GETAC GETAD SETA

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin>3
        error('GETA: too many input')
    end
    
    
    if nargin==1
        A = obj.A;
        return
    end
    
    
    if ischar (i)
        i=obj.name2index(i);
    end
    
    if i>obj.numSys
        error('GETA: system %d not exist yet',i)
    end
    
    
    if nargin==2
        j=i;
    end
    
    if ischar(j)
        j=obj.name2index(j);
    end
    
    if j>obj.numSys
        error('GETA: system %d not exist yet',j)
    end
    
    
    if nargin>=2
        A=obj.A(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),sum(obj.ni(1:j-1))+1:sum(obj.ni(1:j)));
    end
    
end