function Bcen = getBcen(obj,i,j)
% GETBCEN gets the matrix Bcen
% 
% BCEN = objlss.getBCEN(i,j)
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall centralized input matrix BCEN or the matrix BCENij.
% 
% BCEN = objlss.GETBCEN(i,j) return the matrix BCENij which describe coupling
% between system i and centralized input j
% 
% USAGE:
% BCEN = objlss.getBCEN() return the overall matrix BCEN
%
% BCEN = objlss.getBCEN(i) return a matrix BCEN
% containing all centralized input different from zero that act on system i
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the first system
% 
% j = number or name of the centralized system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% BCEN desired matrix
% 
%
% see also ADDCENTRALIZEDINPUT 

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if isempty(obj.Bcen)
        Bcen = zeros(sum(obj.ni),obj.numICen);
    else
        Bcen = obj.Bcen;
    end
    
    if nargin ==1
        return
    end
    
    if ischar(i)
        i=name2index(i);
    end
    
    %if j is not in input take all exogenous signals different from zero
    if nargin==2
        Bcen=obj.Bcen(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),:);
        mask=any(Bcen~=0);
        Bcen=Bcen(:,mask);
        return
    end
    
    %if j is in input take j-th exogenous signal
    if nargin==3
        Bcen=obj.Bcen(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),j);
    end
    
end