function C = getC(obj,i,j)
% GETC gets the matrix C
% 
% C = objlss.getC(i,j)
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall matrix C or the matrix Cij.
% 
% C = objlss.GETC(i,j) return the output coupling between system i and j
% 
% USAGE:
% C = objlss.getC() return the overall output matrix C
%
% C = objlss.getC(i) return the local output matrix Cii of system i
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the first system
% 
% j = number or name of the second system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% C desired output matrix
% 
%
% see also GETCD GETCC

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin>3
        error('GETC: too many input')
    end
    
    if nargin>=1
        if ~isempty(obj.C)
            C = obj.C;
            pi=obj.pi;
        else
            C = sparse(eye(sum(obj.ni)));
            pi=obj.ni;
        end
    end
    
    if nargin==1
        return
    end
    
    if ischar (i)
        i=obj.name2index(i);
    end
    
    if i>obj.numSys
        error('GETC: system %d not exist yet',i)
    end
    
    if nargin==2
        j=i;
    end
    
    if ischar (j)
        j=obj.name2index(ji);
    end
    
    if j>obj.numSys
        error('GETC: system %d not exist yet',j)
    end
    
    if nargin>=2
        
        C=C(sum(pi(1:i-1))+1:sum(pi(1:i)),sum(obj.ni(1:j-1))+1:sum(obj.ni(1:j)));
        
    end
end