function D = getD(obj,i,j)
% GETD gets the matrix D
% 
% D = objlss.getD(i,j)
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall matrix D or the matrix Dij.
% 
% D = objlss.GETD(i,j) return the output coupling between system i and j
% 
% USAGE:
% D = objlss.getD() return the overall output matrix D
%
% D = objlss.getD(i) return the local output matrix Dii of system i
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the first system
% 
% j = number or name of the second system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% D desired output matrix
% 
%
% see also GETDC GETDD

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin>3
        error('GETD: too many input')
    end
    
    if nargin>=1
        if ~isempty(obj.C)
            pi=obj.pi;
        else
            pi=obj.ni;
        end
        
        if ~isempty(obj.D)
            D = obj.D;
        else
            D = sparse(zeros(sum(pi),sum(obj.mi)));
        end
    end
    
    if nargin==1
        return
    end
    
    if ischar (i)
        i=obj.name2index(i);
    end
    
    if i>obj.numSys
        error('GETD: system %d not exist yet',i)
    end
    
    if nargin==2
        j=i;
    end
    
    if ischar (j)
        j=obj.name2index(j);
    end
    
    if j>obj.numSys
        error('GETD: system %d not exist yet',j)
    end
    
    if nargin>=2
        
        D=D(sum(pi(1:i-1))+1:sum(pi(1:i)),sum(obj.mi(1:j-1))+1:sum(obj.mi(1:j)));
        
    end
end