function N  = getN(obj,i,j)
% GETN gets the matrix N
% 
% N = objlss.getN(i,j)
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return the overall matrix N or the matrix Nij.
% 
% N = objlss.GETN(i,j) return the matrix Nij which describe coupling
% between system i and exogenous signal j
% 
% USAGE:
% N = objlss.getN() return the overall matrix N
%
% N = objlss.getN(i) return a matrix N
% containing all exogenous signals different from zero that act on system i
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the first system
% 
% j = index of the exogenous input
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% N desired matrix
% 
%
% see also ADDEXOINPUT

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin>3
        error('GETN: too many input')
    end
    
    if isempty(obj.pi)
        pi = obj.ni;
    else
        pi = obj.pi;
    end
    
    if isempty(obj.N)
        N = sparse(zeros(sum(pi),obj.numExo));
    else
        N = obj.N;
    end
    
    if nargin==1
        return
    end
    
    if ischar(i)
        i=obj.name2index(i);
    end
    
    if i>obj.numSys
        error('GETN: system %d not exist yet',i)
    end
    
    %if j is not in input take all exogenous signals different from zero
    if nargin==2
        N=obj.N(sum(pi(1:i-1))+1:sum(pi(1:i)),:);
        mask=any(N~=0);
        N=N(:,mask);
        return
    end
    
    %if j is in input take j-th exogenous signal
    if nargin==3
        if isempty(N)
            N = N(sum(pi(1:i-1))+1:sum(pi(1:i)),:);
        else
            N = N(sum(pi(1:i-1))+1:sum(pi(1:i)),j);
        end
    end
end