function sub = getSystem(obj,i)
% GETSYSTEM get a subsystem (as subss object) from a large-scale system (lss object)
% 
% objsub = objlss.getSystem(i)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Get a subsystem with all properties of a subss object
%
% objsub=objlss.GETSYSTEM(i)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------  
% i index or name of the involved subsystem 
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------   
% objsub = subsystem i (subss object)
% 
%
% see also ADDSYSTEM SUBSS

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ischar(i)
        i=name2index(obj,i);
    end
    
    A=obj.getA(i);
    B=obj.getB(i);
    
    if isempty (obj.C) && isempty(obj.D)
        if size(B,2)==0
            B = [];
        end
        sub=subss(A,B,[],[],obj.name{1,i},obj.Ts);
    else
        C=obj.getC(i);
        D=obj.getD(i);
        sub=subss(A,B,C,D,obj.name{1,i},obj.Ts);
    end
    
    sub = setCoupling(sub,obj,i);
    
    if ~isempty(obj.rx) && obj.rx(i)~=0
        [Hx, Kx] = obj.doubleStateConstraint(i);
        sub=sub.addStateConstraint(Hx,Kx);
    end
    
    if ~isempty(obj.ru) && obj.ru(i)~=0
        [Hu, Ku] = obj.doubleInputConstraint(i);
        sub = sub.addInputConstraint(Hu,Ku);
    end
    
    if ~isempty(obj.ry) && obj.ry(i)~=0
        [Hy, Ky] = obj.doubleOutConstraint(i);
        sub=sub.addOutConstraint(Hy,Ky);
    end
    
    if ~isempty(obj.Hd)
        [Hd,Kd]= obj.doubleExoConstraintOnSystem(i);
        sub=sub.addExoConstraint(Hd,Kd);
    end
    
    if ~isempty(obj.Hcen)
        [Hcen,Kcen]= obj.doubleCenInputConstraintOnSystem(i);
        sub=sub.addCentralizedInputConstraint(Hcen,Kcen);
    end
    
    if ~isempty(obj.re) && obj.re(i)~=0
        [He, Ke] = obj.doubleErrorEstimationConstraint(i);
        sub=sub.addErrorEstimationConstraint(He,Ke);
    end
    
    if ~isempty(obj.rdeltau) && obj.rdeltau(i)~=0
        [Hdeltau, Kdeltau] = obj.doubleDeltaUConstraint(i);
        sub=sub.addErrorEstimationConstraint(Hdeltau,Kdeltau);
    end
    
end