function lssout = join( lss1 , lss2 )
% JOIN Joins two lss objects in one
%
% lssout = join(lss1,lss2)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% The lssout object is the union of lss1 and lss2
%
% lssout = JOIN(lss1,lss2);
%   
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% lss1 and lss2 are lss objects
%  
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% lssout = new lss object
% 
% see also LSS

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if ~isa(lss1,'lss')|| ~isa(lss2,'lss')
        error('JOIN: input arguments must be lss objects')
    end
    
    if lss1.Ts ~= lss2.Ts
        error('JOIN: input arguments must have same Ts')
    end
    
    lssout = lss();
    lssout.numSys = lss1.numSys+lss2.numSys;
    lssout.Ts = lss1.Ts;
    lssout.A = blkdiag(lss1.A,lss2.A);
    lssout.B = blkdiag(lss1.B,lss2.B);
    lssout.ni = [lss1.ni,lss2.ni];
    lssout.mi = [lss1.mi,lss2.mi];
    
    %state constraint
    if ~isempty(lss1.Hx) || ~isempty(lss2.Hx)
        if isempty(lss1.rx)
            lss1.rx = zeros(1,lss1.numSys);
        end
        if isempty(lss2.rx)
            lss2.rx = zeros(1,lss2.numSys);
        end
        lssout.rx = [lss1.rx,lss2.rx];
        H1 = [lss1.Hx(1:sum(lss1.rx),:),zeros(sum(lss1.rx),sum(lss2.ni))];
        H2 = [zeros(sum(lss2.rx),sum(lss1.ni)),lss2.Hx(1:sum(lss2.rx),:)];
        Haux1 = [lss1.Hx(sum(lss1.rx)+1:end,:),zeros(size(lss1.Hx,1)-sum(lss1.rx),sum(lss2.ni))];
        Haux2 = [zeros(size(lss2.Hx,1)-sum(lss2.rx),sum(lss1.ni)),lss2.Hx(sum(lss2.rx)+1:end,:)];
        K1 = lss1.Kx(1:sum(lss1.rx));
        K2 = lss2.Kx(1:sum(lss2.rx));
        
        if ~isempty(H1) && isempty(H2)
            lssout.Hx = H1;
        end
        if isempty(H1) && ~isempty(H2)
            lssout.Hx = H2;
        end
        if ~isempty(H1) && ~isempty(H2)
            lssout.Hx = [H1;H2];
        end
        if ~isempty(Haux1)
            lssout.Hx = [lssout.Hx;Haux1];
        end
        if ~isempty(Haux2)
            lssout.Hx = [lssout.Hx;Haux2];
        end
        lssout.Kx = [K1;K2;lss1.Kx(sum(lss1.rx)+1:end);lss2.Kx(sum(lss2.rx)+1:end)];
    end
    
    %input constraint
    if ~isempty(lss1.Hu) || ~isempty(lss2.Hu)
        if isempty(lss1.ru)
            lss1.ru = zeros(1,lss1.numSys);
        end
        if isempty(lss2.ru)
            lss2.ru = zeros(1,lss2.numSys);
        end
        lssout.ru = [lss1.ru,lss2.ru];
        H1 = [lss1.Hu(1:sum(lss1.ru),:),zeros(sum(lss1.ru),sum(lss2.mi))];
        H2 = [zeros(sum(lss2.ru),sum(lss1.mi)),lss2.Hu(1:sum(lss2.ru),:)];
        Haux1 = [lss1.Hu(sum(lss1.ru)+1:end,:),zeros(size(lss1.Hu,1)-sum(lss1.ru),sum(lss2.mi))];
        Haux2 = [zeros(size(lss2.Hu,1)-sum(lss2.ru),sum(lss1.mi)),lss2.Hu(sum(lss2.ru)+1:end,:)];
        K1 = lss1.Ku(1:sum(lss1.ru));
        K2 = lss2.Ku(1:sum(lss2.ru));
        
        if ~isempty(H1) && isempty(H2)
            lssout.Hu = H1;
        end
        if isempty(H1) && ~isempty(H2)
            lssout.Hu = H2;
        end
        if ~isempty(H1) && ~isempty(H2)
            lssout.Hu = [H1;H2];
        end
        if ~isempty(Haux1)
            lssout.Hu = [lssout.Hu;Haux1];
        end
        if ~isempty(Haux2)
            lssout.Hu = [lssout.Hu;Haux2];
        end
        lssout.Ku = [K1;K2;lss1.Ku(sum(lss1.ru)+1:end);lss2.Ku(sum(lss2.ru)+1:end)];
    end
    
    %delta u constraint
    if ~isempty(lss1.Hdeltau) || ~isempty(lss2.Hdeltau)
        if isempty(lss1.rdeltau)
            lss1.rdeltau = zeros(1,lss1.numSys);
        end
        if isempty(lss2.rdeltau)
            lss2.rdeltau = zeros(1,lss2.numSys);
        end
        lssout.rdeltau = [lss1.rdeltau,lss2.rdeltau];
        H1 = [lss1.Hdeltau(1:sum(lss1.rdeltau),:),zeros(sum(lss1.rdeltau),sum(lss2.mi))];
        H2 = [zeros(sum(lss2.rdeltau),sum(lss1.mi)),lss2.Hdeltau(1:sum(lss2.rdeltau),:)];
        Haux1 = [lss1.Hdeltau(sum(lss1.rdeltau)+1:end,:),zeros(size(lss1.Hdeltau,1)-sum(lss1.rdeltau),sum(lss2.mi))];
        Haux2 = [zeros(size(lss2.Hdeltau,1)-sum(lss2.rdeltau),sum(lss1.mi)),lss2.Hdeltau(sum(lss2.rdeltau)+1:end,:)];
        K1 = lss1.Kdeltau(1:sum(lss1.rdeltau));
        K2 = lss2.Kdeltau(1:sum(lss2.rdeltau));
        if ~isempty(H1) && isempty(H2)
            lssout.Hdeltau = H1;
        end
        if isempty(H1) && ~isempty(H2)
            lssout.Hdeltau = H2;
        end
        if ~isempty(H1) && ~isempty(H2)
            lssout.Hdeltau = [H1;H2];
        end
        if ~isempty(Haux1)
            lssout.Hdeltau = [lssout.Hdeltau;Haux1];
        end
        if ~isempty(Haux2)
            lssout.Hdeltau = [lssout.Hdeltau;Haux2];
        end
        lssout.Kdeltau = [K1;K2;lss1.Kdeltau(sum(lss1.rdeltau)+1:end);lss2.Kdeltau(sum(lss2.deltau)+1:end)];
    end
    
    if ~isempty(lss1.C) || ~isempty(lss2.C)
        lssout.C = blkdiag(lss1.getC,lss2.getC);
    end
    if ~isempty(lss1.D) || ~isempty(lss2.D)
        lssout.D = blkdiag(lss1.getD,lss2.getD);
    end
    lssout.pi = [lss1.pi, lss2.pi];
    
    %Out constraint
    if ~isempty(lss1.Hy) || ~isempty(lss2.Hy)
        if isempty(lss1.ry)
            lss1.ry = zeros(1,lss1.numSys);
        end
        if isempty(lss2.ry)
            lss2.ry = zeros(1,lss2.numSys);
        end
        lssout.ry = [lss1.ry,lss2.ry];
        H1 = [lss1.Hy(1:sum(lss1.ry),:),zeros(sum(lss1.ry),sum(lss2.pi))];
        H2 = [zeros(sum(lss2.ry),sum(lss1.pi)),lss2.Hy(1:sum(lss2.ry),:)];
        Haux1 = [lss1.Hy(sum(lss1.ry)+1:end,:),zeros(size(lss1.Hy,1)-sum(lss1.ry),sum(lss2.pi))];
        Haux2 = [zeros(size(lss2.Hy,1)-sum(lss2.ry),sum(lss1.pi)),lss2.Hy(sum(lss2.ry)+1:end,:)];
        K1 = lss1.Ky(1:sum(lss1.ry));
        K2 = lss2.Ky(1:sum(lss2.ry));
        if ~isempty(H1) && isempty(H2)
            lssout.Hy = H1;
        end
        if isempty(H1) && ~isempty(H2)
            lssout.Hy = H2;
        end
        if ~isempty(H1) && ~isempty(H2)
            lssout.Hy = [H1;H2];
        end
        if ~isempty(Haux1)
            lssout.Hy = [lssout.Hy;Haux1];
        end
        if ~isempty(Haux2)
            lssout.Hy = [lssout.Hy;Haux2];
        end
        lssout.Ky = [K1;K2;lss1.Ky(sum(lss1.ry)+1:end);lss2.Ky(sum(lss2.ry)+1:end)];
    end
    
    %Exo signal
    lssout.numExo = lss1.numExo+lss2.numExo;
    
    if lssout.numExo>0
        %M both systems
        if ~isempty (lss1.M) && ~isempty (lss2.M)
            lssout.M = blkdiag(lss1.M,lss2.M);
        end
        
        %M first lss object
        if ~isempty(lss1.M) && isempty(lss2.M)
            Maux1 = zeros(sum(lss2.ni),lss1.numExo);
            lssout.M = [lss1.M;Maux1];
        end
        %M second lss object
        if isempty(lss1.M) && ~isempty(lss2.M)
            Maux2 = zeros(sum(lss1.ni),lss2.numExo);
            lssout.M = [Maux2;lss2.M];
        end
        
        %N both systems
        if ~isempty (lss1.N) && ~isempty (lss2.N)
            lssout.N = blkdiag(lss1.N,lss2.N);
        end
        
        %N first lss object
        if ~isempty(lss1.N) && isempty(lss2.N)
            Naux1 = zeros(sum(lss2.pi),lss1.numExo);
            lssout.N = [lss1.N;Naux1];
        end
        %N second lss object
        if isempty(lss1.N) && ~isempty(lss2.N)
            Naux2 = zeros(sum(lss1.pi),lss2.numExo);
            lssout.N = [Naux2;lss2.N];
        end
        
        %exo constraint
        if ~isempty(lss1.Hd) || ~isempty(lss2.Hd)
            if isempty(lss1.rd)
                lss1.rd = zeros(1,lss1.numSys);
            end
            if isempty(lss2.rd)
                lss2.rd = zeros(1,lss2.numSys);
            end
            lssout.rd = [lss1.rd,lss2.rd];
            H1 = [lss1.Hd(1:sum(lss1.rd),:),zeros(sum(lss1.rd),lss2.numExo)];
            H2 = [zeros(sum(lss2.rd),lss1.numExo),lss2.Hd(1:sum(lss2.rd),:)];
            Haux1 = [lss1.Hd(sum(lss1.rd)+1:end,:),zeros(size(lss1.Hd,1)-sum(lss1.rd),lss2.numExo)];
            Haux2 = [zeros(size(lss2.Hd,1)-sum(lss2.rd),lss1.numExo),lss2.Hd(sum(lss2.rd)+1:end,:)];
            K1 = lss1.Kd(1:sum(lss1.rd));
            K2 = lss2.Kd(1:sum(lss2.rd));
            if ~isempty(H1) && isempty(H2)
                lssout.Hd = H1;
            end
            if isempty(H1) && ~isempty(H2)
                lssout.Hd = H2;
            end
            if ~isempty(H1) && ~isempty(H2)
                lssout.Hd = [H1;H2];
            end
            if ~isempty(Haux1)
                lssout.Hd = [lssout.Hd;Haux1];
            end
            if ~isempty(Haux2)
                lssout.Hd = [lssout.Hd;Haux2];
            end
            lssout.Kd = [K1;K2;lss1.Kd(sum(lss1.rd)+1:end);lss2.Kd(sum(lss2.rd)+1:end)];
        end
    end
    
    
    %Icen signal
    lssout.numICen = lss1.numICen+lss2.numICen;
    if lssout.numICen>0
        %Bcen both systems
        if ~isempty (lss1.Bcen) && ~isempty (lss2.Bcen)
            lssout.Bcen = blkdiag(lss1.Bcen,lss2.Bcen);
        end
        
        %Bcen first lss object
        if ~isempty(lss1.Bcen) && isempty(lss2.Bcen)
            Baux1 = zeros(sum(lss2.ni),lss1.numICen);
            lssout.Bcen = [lss1.Bcen;Baux1];
        end
        %Bcen second lss object
        if isempty(lss1.Bcen) && ~isempty(lss2.Bcen)
            Baux2 = zeros(sum(lss1.ni),lss2.numICen);
            lssout.Bcen = [Baux2;lss2.Bcen];
        end
        
        %Dcen both systems
        if ~isempty (lss1.Dcen) && ~isempty (lss2.Dcen)
            lssout.Dcen = blkdiag(lss1.Dcen,lss2.Dcen);
        end
        
        % Dcen first lss system
        if ~isempty(lss1.Dcen) && isempty(lss2.Dcen)
            Daux1 = zeros(sum(lss2.pi),lss1.numICen);
            lssout.Dcen = [lss1.Dcen;Daux1];
        end
        %Dcen second lss system
        if isempty(lss1.Dcen) && ~isempty(lss2.Dcen)
            Daux2 = zeros(sum(lss1.pi),lss2.numICen);
            lssout.Dcen = [Daux2;lss2.Dcen];
        end
        
        %ceninput constraint
        if ~isempty(lss1.Hcen) || ~isempty(lss2.Hcen)
            if isempty(lss1.rcen)
                lss1.rcen = zeros(1,lss1.numSys);
            end
            if isempty(lss2.rcen)
                lss2.rcen = zeros(1,lss2.numSys);
            end
            lssout.rcen = [lss1.rcen,lss2.rcen];
            H1 = [lss1.Hcen(1:sum(lss1.rcen),:),zeros(sum(lss1.rcen),lss2.numICen)];
            H2 = [zeros(sum(lss2.rcen),lss1.numICen),lss2.Hcen(1:sum(lss2.rcen),:)];
            Haux1 = [lss1.Hcen(sum(lss1.rcen)+1:end,:),zeros(size(lss1.Hcen,1)-sum(lss1.rcen),lss2.numICen)];
            Haux2 = [zeros(size(lss2.Hcen,1)-sum(lss2.rcen),lss1.numICen),lss2.Hcen(sum(lss2.rcen)+1:end,:)];
            K1 = lss1.Kcen(1:sum(lss1.rcen));
            K2 = lss2.Kcen(1:sum(lss2.rcen));
            if ~isempty(H1) && isempty(H2)
                lssout.Hcen = H1;
            end
            if isempty(H1) && ~isempty(H2)
                lssout.Hcen = H2;
            end
            if ~isempty(H1) && ~isempty(H2)
                lssout.Hcen = [H1;H2];
            end
            if ~isempty(Haux1)
                lssout.Hcen = [lssout.Hcen;Haux1];
            end
            if ~isempty(Haux2)
                lssout.Hcen = [lssout.Hcen;Haux2];
            end
            lssout.Kcen = [K1;K2;lss1.Kcen(sum(lss1.rcen)+1:end);lss2.Kcen(sum(lss2.rcen)+1:end)];
        end
    end
    
    % errorestimation constraint
    if ~isempty(lss1.He) || ~isempty(lss2.He)
        if isempty(lss1.re)
            lss1.re = zeros(1,lss1.numSys);
        end
        if isempty(lss2.re)
            lss2.re = zeros(1,lss2.numSys);
        end
        lssout.re = [lss1.re,lss2.re];
        H1 = [lss1.He(1:sum(lss1.re),:),zeros(sum(lss1.re),sum(lss2.ni))];
        H2 = [zeros(sum(lss2.re),sum(lss1.ni)),lss2.He(1:sum(lss2.re),:)];
        Haux1 = [lss1.He(sum(lss1.re)+1:end,:),zeros(size(lss1.He,1)-sum(lss1.re),sum(lss2.ni))];
        Haux2 = [zeros(size(lss2.He,1)-sum(lss2.re),sum(lss1.ni)),lss2.He(sum(lss2.re)+1:end,:)];
        K1 = lss1.Ke(1:sum(lss1.re));
        K2 = lss2.Ke(1:sum(lss2.re));
        if ~isempty(H1) && isempty(H2)
            lssout.He = H1;
        end
        if isempty(H1) && ~isempty(H2)
            lssout.He = H2;
        end
        if ~isempty(H1) && ~isempty(H2)
            lssout.He = [H1;H2];
        end
        if ~isempty(Haux1)
            lssout.He = [lssout.He;Haux1];
        end
        if ~isempty(Haux2)
            lssout.He = [lssout.He;Haux2];
        end
        lssout.Ke = [K1;K2;lss1.Ke(sum(lss1.re)+1:end);lss2.Ke(sum(lss2.re)+1:end)];
    end
    
    %couplingmatrix and names
    lssout.couplingmatrix = sparse([ lss1.couplingmatrix false(lss1.numSys,lss2.numSys) ; false(lss2.numSys,lss1.numSys) lss2.couplingmatrix ]);
    for k=1:lssout.numSys
        if k<= lss1.numSys
            lssout.name{1,k} = strcat ('lss1 ',lss1.name{1,k});
        else
            lssout.name{1,k} = strcat ('lss2 ',lss2.name{1,k-lss2.numSys});
        end
    end
    
    lssout.namex = [lss1.namex,lss2.namex];
    lssout.nameu = [lss1.nameu, lss2.nameu];
    lssout.namey = [lss1.namey,lss2.namey];
    lssout.named = [lss1.named,lss2.named];
    lssout.nameucen = [lss1.nameucen,lss2.nameucen];
end