function k = name2index(obj,name)
% NAME2INDEX Transforms the name of a subsystem (contained in an LSS) in its index number
%
% k = objlss.name2index(name)
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Transforms the name of a subsystem in the lss object objlss in its index number
%
% k = objlss.NAME2INDEX(name)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% name = name of the system
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% k = number of the system called name.
% 


% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end    

    for k=1:size(obj.name,2)
        if strcmp(name,obj.name{k})
            return
        end
    end
    
    error('NAME2INDEX: no system with name %s',name)
    
end