function obj = removeCentralizedInput( obj,i )
% REMOVECENTRALIZEDINPUT remove centralized input i
% 
% objlss = objlss.removeCentralizedInput (i)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Remove centralized input i and its constraints from the lss object objlss
%
% Note that a coupling constraint related to centralized inputs i and j , 
% after the removal of i becomes a local constraint of j. 
% 
% objlss = objlss.REMOVECENTRALIZEDINPUT(i)
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------  
% i = number of the centralized input to remove.
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------  
% objlss with updated numICen, Bcen, Dcen, Hcen, Kcen
% 
%
% see also ADDCENTRALIZEDINPUT REMOVECONSTRAINT

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin~=2
        error('REMOVECENTRALIZEDINPUT: parameters in input')
    end
    
    if i>obj.numICen
        error('REMOVECENTRALIZEDINPUT: centralized input %d not yet inserted',i)
    end
    obj.Bcen(:,i)=[];
    if ~isempty(obj.Dcen)
        obj.Dcen(:,i)=[];
    end
    obj.numICen = obj.numICen-1;
    
    if obj.numICen == 0
        obj.Bcen = [];
        obj.Dcen = [];
        
    end
    
    
    if ~isempty(obj.Hcen)
        if size(obj.Hcen,1)~=sum(obj.rcen)
            obj.Hcen(:,i)=zeros(size(obj.Hcen,1),1);
            obj.Hcen(sum(obj.rcen(1:i-1))+1:sum(obj.rcen(1:i)),:)=zeros(obj.rcen(i),size(obj.Hcen,2));
            obj.Kcen(sum(obj.rcen(1:i-1))+1:sum(obj.rcen(1:i)))=zeros(obj.rcen(i),1);
            Haux=obj.Hcen(sum(obj.rcen)+1:end,:);
            Kaux=obj.Kcen(sum(obj.rcen)+1:end,1);
            flag=[];
            for j=1:size(Haux,1)
                for k=1:obj.numICen
                    help=Haux(j,k);
                    flag(j,k)=any(help~=0);
                    
                end
            end
            flagrow=(sum(flag,2)>1.5);
            index=0;
            numsys = [];
            daspostare  = Haux(~flagrow,:);
            daspostarek = Kaux(~flagrow);
            
            for j=1:size(daspostare,1)
                for k=1:obj.numICen
                    index=index+1;
                    if flag(j,k)~=0
                        break
                    end
                end
                numsys(end+1,1)=index;
                index=0;
            end
            
            aux=obj.Hcen(1:sum(obj.rcen),:);
            auxk=obj.Kcen(1:sum(obj.rcen));
            for j=1:size(numsys,1)
                aux  =  [aux(1:sum(obj.rcen(1:numsys(j))),:); daspostare(j,:); aux(sum(obj.rcen(1:numsys(j)))+1:sum(obj.rcen),:)];
                auxk =  [auxk(1:sum(obj.rcen(1:numsys(j)))); daspostarek(j) ; auxk(sum(obj.rcen(1:numsys(j)))+1:sum(obj.rcen))];
                obj.rcen(numsys(j))=obj.rcen(numsys(j))+1;
            end
            
            obj.Hcen = [aux ; Haux(flagrow,:)];
            obj.Kcen = [auxk; Kaux(flagrow)];
        end
        
        obj.numICen=obj.numICen-1;
        obj.Hcen(:,i)=[];
        obj.Hcen(sum(obj.rcen(1:i-1))+1:sum(obj.rcen(1:i)),:)=[];
        obj.Kcen(sum(obj.rcen(1:i-1))+1:sum(obj.rcen(1:i)))=[];
        obj.rcen(i)=[];
        
    end
    
    if ~isempty(obj.nameucen) && ~isempty(obj.nameucen(i))
        obj.nameucen (i) =[];
    end
    
    
end