function obj = removeCoupling(obj,i,j,how)
% REMOVECOUPLING Removes a coupling between two subsystems 
%  
% objlss = objlss.removeCoupling (i,j,how)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Remove a coupling term from subsystem j to subsystem i (e.g. the block
% Aij in the matrix A in the lss object objlss)
% 
% objlss = objlss.REMOVECOUPLING (i,j,how)
% 
% USAGE:
% 
% objlss = objlss.removeCoupling (i,j)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
%  i = name or number of the first system
% 
%  j = name or number of the second system
% 
%  how = 'a' remove the coupling between i and j in the A matrix 
%  how = 'b' remove the coupling between i and j in the B matrix 
%  how = 'c' remove the coupling between i and j in the C matrix 
%  how = 'd' remove the coupling between i and j in the D matrix
% 
%  If how is not passed as input, all blocks Aij, Bij, Cij and Dij will be
%  zeroed.
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with new A,B,C,D matrix
% 
%
% see also ADDCOUPLING

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ischar(i)
        i=obj.name2index(i);
    end
    
    if ischar(j)
        j=obj.name2index(j);
    end
    
    if nargin>3
        if ~ischar(how)
            error('REMOVECOUPLING: see help removeCoupling')
        end
        if ~strcmp(how,'a')&&~strcmp(how,'b')&&~strcmp(how,'c')&&~strcmp(how,'d')
            error('REMOVECOUPLING: fourth parameter must be a or b or c or d')
        end
    end
    
    if nargin==3 || strcmp(how,'a')
        obj=obj.setA(zeros(obj.ni(i)),i,j);
    end
    
    if nargin==3 || strcmp(how,'b')
        obj=obj.setB(zeros(obj.ni(i),obj.mi(j)),i,j);
    end
    
    if nargin==3 || strcmp(how,'c')
        obj=obj.setC(zeros(obj.pi(i),obj.ni(j)),i,j);
    end
    
    if nargin==3 || strcmp(how,'d')
        obj=obj.setD(zeros(obj.pi(i),obj.mi(j)),i,j);
    end
    
end