function obj = removeExoInput(obj,i)
% REMOVEEXOINPUT Removes exogenous signal i
% 
% objlss = objlss.removeExoInput (i)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Remove exogenous input i and its constraints
%
% Note that a coupling constraint related to exogenous signals i and j, 
% after the removal of the signal i becomes a local constraint of signal j. 
% 
% objlss = objlss.REMOVEEXOINPUT (i)
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------  
% i = index of the exogenous signal stored in objlss
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------  
% objlss with updated numExo, M, N, Hd, Kd
% 
%
% see also ADDEXOINPUT REMOVECONSTRAINT

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin~=2
        error('REMOVEEXOINPUT: parameters in input')
    end
    
    if i>obj.numExo
        error('REMOVEEXOINPUT: exogenous signal %d not yet inserted',i)
    end
    
    iv = i;
    cont = 0;
    
    for itemp = iv
        
        i = itemp - cont;
        
        if ~isempty(obj.M)
            obj.M(:,i)= [];
        end
        if ~isempty(obj.N)
            obj.N(:,i) =[];
        end
        
        % remove constraint on exogenous signal i
        if ~isempty(obj.Hd)
            if size(obj.Hd,1)~=sum(obj.rd)
                obj.Hd(:,i)=zeros(size(obj.Hd,1),1);
                obj.Hd(sum(obj.rd(1:i-1))+1:sum(obj.rd(1:i)),:)=zeros(obj.rd(i),size(obj.Hd,2));
                obj.Kd(sum(obj.rd(1:i-1))+1:sum(obj.rd(1:i)))=zeros(obj.rd(i),1);
                Haux=obj.Hd(sum(obj.rd)+1:end,:);
                Kaux=obj.Kd(sum(obj.rd)+1:end,1);
                flag=[];
                for j=1:size(Haux,1)
                    for k=1:obj.numExo
                        help=Haux(j,k);
                        flag(j,k)=any(help~=0);
                        
                    end
                end
                flagrow=(sum(flag,2)>1.5);
                index=0;
                numsys = [];
                daspostare  = Haux(~flagrow,:);
                daspostarek = Kaux(~flagrow);
                
                for j=1:size(daspostare,1)
                    for k=1:obj.numExo
                        index=index+1;
                        if flag(j,k)~=0
                            break
                        end
                    end
                    numsys(end+1,1)=index;
                    index=0;
                end
                
                aux=obj.Hd(1:sum(obj.rd),:);
                auxk=obj.Kd(1:sum(obj.rd));
                for j=1:size(numsys,1)
                    aux  =  [aux(1:sum(obj.rd(1:numsys(j))),:); daspostare(j,:); aux(sum(obj.rd(1:numsys(j)))+1:sum(obj.rd),:)];
                    auxk =  [auxk(1:sum(obj.rd(1:numsys(j)))); daspostarek(j) ; auxk(sum(obj.rd(1:numsys(j)))+1:sum(obj.rd))];
                    obj.rd(numsys(j))=obj.rd(numsys(j))+1;
                end
                
                obj.Hd = [aux ; Haux(flagrow,:)];
                obj.Kd = [auxk; Kaux(flagrow)];
            end
            obj.numExo=obj.numExo-1;
            
            if obj.numExo ==0
                obj.M = [];
                obj.N = [];
            end
            
            obj.Hd(:,i)=[];
            obj.Hd(sum(obj.rd(1:i-1))+1:sum(obj.rd(1:i)),:)=[];
            obj.Kd(sum(obj.rd(1:i-1))+1:sum(obj.rd(1:i)))=[];
            obj.rd(i)=[];
            
        end
        if ~isempty(obj.named) && ~isempty(obj.named(i))
            obj.named (i) =[];
        end
        
        cont = cont + 1;
        
    end
end