function obj = setA(obj,Aij,i,j)
% SETA Sets a new matrix A in an LSS
% 
% objlss = objlss.setA(Aij,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix A (or a part of it) of the lss object objlss
%
% objlss = objlss.setA(Aij,i,j) sets the coupling matrix Aij, i.e. the
% state coupling from subsystem i to j. The input matrix Aij must have
% dimensions n(i) x n(j)
%
% 
% objlss = objlss.setA(A) sets the overall matrix A. The matrix input
% (matrix A) must have dimensions n x n
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Aij = new matrix Aij
% 
% i = number or name of the first system
% 
% j = number or name of the second system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new matrix A
% 
%
% see also GETA
    
% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    [Aijr, Aijc]=size(Aij);
    if nargin==2
        [Ar, Ac]=size(obj.A);
        if Ar==Aijr && Ac==Aijc
            obj.A = sparse(Aij);
        end
        return
    end
    
    if ischar(i)==1
        i=name2index(obj,i);
    end
    
    if nargin==3
        j=i;
    end
    
    if nargin==4
        if(ischar(j))
            j=name2index(obj,j);
        end
    end
    
    if Aijr~= obj.ni(i)
        error('SETA: Aij rows=%d ~= ni(&d)=%d',Aijr,i,obj.ni(i))
    end
    
    if Aijc~=obj.ni(j)
        error('SETA: Aij columns=%d ~= ni(%d)=%d',Aijc,j,obj.ni(j))
    end
    
    obj.A(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),sum(obj.ni(1:j-1))+1:sum(obj.ni(1:j)))=Aij;
    if ~all(all(Aij==0))
        obj.couplingmatrix(i,j) = true;
    end
end