function obj = setB(obj,Bij,i,j)
% SETB Sets a new matrix B in an LSS
% 
% objlss = objlss.setB(Bij,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix B (or a part of it) of the lss object objlss
%
% objlss = objlss.setB(Bij,i,j) sets the coupling matrix Bij, i.e. the
% input coupling from subsystem i to j. The input matrix Bij must have
% dimensions n(i) x m(j)
%
% 
% objlss = objlss.setB(B) sets the overall matrix B. The matrix input
% (matrix B) must have dimensions n x m
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Bij = new matrix Bij
% 
% i = number or name of the first system
% 
% j = number or name of the second system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new B matrix 
% 
%
% see also GETB
    
% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    [Bijr, Bijc]=size(Bij);
    if nargin==2
        [Br, Bc]=size(obj.B);
        if Br==Bijr && Bc==Bijc
            obj.B = sparse(Bij);
        end
        return
    end
    
    if ischar(i)==1
        i=name2index(obj,i);
    end
    
    if nargin==3
        j=i;
    end
    
    if nargin==4
        if(ischar(j))
            j=name2index(obj,j);
        end
    end
    
    
    if Bijr~= obj.ni(i)
        error('SETB: Bij rows=%d ~= ni(&d)=%d',Bijr,i,obj.ni(i))
    end
    if Bijc~=obj.mi(j)
        error('SETB: Bij columns=%d ~= mi(%d)=%d',Bijc,j,obj.mi(j))
    end
    
    obj.B(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),sum(obj.mi(1:j-1))+1:sum(obj.mi(1:j)))=Bij;
    if ~all(all(Bij==0))
        obj.couplingmatrix (i,j) = true;
    end
end