function obj = setBcen(obj,Bcen,i,j)
% SETBCEN Sets a new matrix Bcen in an LSS
% 
% objlss = objlss.setBcen(Bcen,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix Bcen (or a part of it) of the lss object objlss
%
% objlss = objlss.setBcen(Bcenij,i,j) sets the matrix Bcenij, i.e. the
% coupling from subsystem i to centralized input j. The input matrix Bcenij 
% must have dimensions n(i) x 1
%
% 
% objlss = objlss.setBcen(Bcen) sets the overall matrix Bcen. The matrix input
% (matrix Bcen) must have dimensions n x numIcen
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Bcenij = new matrix Bcenij
% 
% i = number or name of the system interested
% 
% j = number of the centralized inputs
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new Bcen matrix
% 
%
% see also GETBCEN
    
% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin==2
        if obj.numICen==0
            error('SETBCEN: no centralized inputs')
        end
        
        if (size(Bcen,2)~=obj.numICen)
            error('SETBCEN: Bcen columns=%d ~= numICen=%d',size(Bcen,2),obj.numICen)
        end
        if size(Bcen,1)~=sum(obj.pi)
            error('SETBCEN: Bcen rows = %d ~= sum(ni)=%d',size(Bcen,1),sum(obj.ni))
        end
        
        obj.Bcen = sparse(Bcen);
    end
    
    if nargin==4 %Bcen_ij between system i and centralized input j
        if j>obj.numICen
            error('SETBCEN: no centralized input %d',j)
        end
        if ischar(i)
            i=obj.name2index(i);
        end
        
        if size(Bcen,1)~=obj.ni(i)
            error('SETBCEN Bcen rows=%d ~= ni(%d)=%d',size(Bcen,1),i,obj.ni(i))
        end
        
        if size (Bcen,2)~=1
            error('SETBCEN: Bcen rows=%d ~=1',size(Bcen,2))
        end
        
        obj.Bcen(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),j) = sparse(Bcen);
    end
end