function obj = setC(obj,Cij,i,j)
% SETC Sets a new matrix C in an LSS
% 
% objlss = objlss.setC(Cij,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix C (or a part of it) of the lss object objlss
%
% objlss = objlss.setC(Cij,i,j) sets the coupling matrix Cij, i.e. the
% output coupling from subsystem i to j. The input matrix Cij must have
% dimensions p(i) x n(j)
%
% 
% objlss = objlss.setC(C) sets the overall matrix C. The matrix input
% (matrix C) must have dimensions p x n
% 
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Cij = new matrix Cij
% 
% i = number or name of the first system
% 
% j = number or name of the second system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new C matrix
% 
%
% see also GETC

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    [Cijr, Cijc]=size(Cij);
    if nargin==2
        if isempty(obj.C)
            if all(all(Cij==eye(sum(obj.ni))))
                return
            else
                obj.pi  = obj.ni;
                obj.C   = sparse(eye(sum(obj.ni)));
            end
        end
        [Cr, Cc] = size(obj.C);
        if Cr==Cijr && Cc==Cijc
            obj.C = sparse(Cij);
        else
            error('SETC: C dimensions. see help setC')
        end
        return
    end
    
    if ischar(i)==1
        i=name2index(obj,i);
    end
    
    if nargin==3
        j=i;
    end
    
    if nargin==4
        if(ischar(j))
            j=name2index(obj,j);
        end
    end
    
    if isempty(obj.C)
        if i==j && all(all(Cij==eye(obj.ni(i))))==1
            return
        end
        if i~=j && all(all(Cij==zeros(obj.ni(i),obj.mi(i))))==1
            return
        end
        obj.pi=obj.ni;
    end
    
    if Cijr~= obj.pi(i)
        error('SETC: Cij rows=%d ~= pi(&d)=%d',Cijr,i,obj.pi(i))
    end
    if Cijc~=obj.ni(j)
        error('SETC: Cij columns=%d ~= ni(%d)=%d',Cijc,j,obj.ni(j))
    end
    
    if isempty(obj.C)
        obj.C=sparse(eye(sum(obj.ni)));
    end
    
    obj.C(sum(obj.pi(1:i-1))+1:sum(obj.pi(1:i)),sum(obj.ni(1:j-1))+1:sum(obj.ni(1:j)))=Cij;
    
    if ~all(all(Cij==0))
        obj.couplingmatrix (i,j) = true;
    end
end