function obj = setD(obj,Dij,i,j)
% SETD Sets a new matrix D in an LSS
% 
% objlss = objlss.setD(Dij,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix D (or a part of it) of the lss object objlss
%
% objlss = objlss.setD(Dij,i,j) sets the coupling matrix Dij, i.e. the
% input coupling from subsystem i to j. The input matrix Dij must have
% dimensions p(i) x m(j)
%
% 
% objlss = objlss.setD(D) sets the overall matrix D. The matrix input
% (matrix D) must have dimensions p x m
% 

% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Dij = new matrix Dij
% 
% i = number or name of the first system
% 
% j = number or name of the second system
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new D matrix
%    
%
% see also GETD

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------   

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    [Dijr, Dijc]=size(Dij);
    if nargin==2
        if isempty(obj.D) && all(all(Dij==zeros(sum(obj.ni),sum(obj.mi))))
            return
        end
        obj.pi = obj.ni;
        obj.D = sparse(zeros(sum(obj.ni),sum(obj.mi)));
        [Dr, Dc] = size(obj.D);
        if Dr==Dijr && Dc==Dijc
            obj.D = sparse(Dij);
        end
        return
    end
    
    if ischar(i)==1
        i=name2index(obj,i);
    end
    
    if nargin==3
        j=i;
    end
    
    if nargin==4
        if ischar(j)
            j=name2index(obj,j);
        end
    end
    
    if isempty(obj.D)
        if all(all(Dij==0))==1
            return
        end
        obj.pi=obj.ni;
    end
    
    if Dijr~=obj.pi(i)
        error('SETD: Dij rows=%d ~= pi(%d)=%d',Dijr,i,obj.pi(i))
    end
    if Dijc~=obj.mi(j)
        error('SETD: Dij columns=%d ~= mi(%d)=%d',Dijc,j,obj.mi(j))
    end
    
    if isempty(obj.D)
        obj.pi = obj.ni;
        obj.C  = sparse(eye(size(obj.A)));
        obj.D  = sparse(zeros(sum(obj.ni),sum(obj.mi)));
    end
    
    obj.D(sum(obj.pi(1:i-1))+1:sum(obj.pi(1:i)),sum(obj.mi(1:j-1))+1:sum(obj.mi(1:j)))=Dij;
    if ~all(all(Dij==0))
        obj.couplingmatrix(i,j)=true;
    end
end