function obj = setDcen(obj,Dcen,i,j)
% SETDCEN Sets a new matrix Dcen in an LSS
% 
% objlss = objlss.setDcen(Dcen,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix Dcen (or a part of it) of the lss object objlss
%
% objlss = objlss.setDcen(Dcenij,i,j) sets the matrix Dcenij, i.e. the
% coupling from subsystem i to centralized input j. The input matrix Dcenij 
% must have dimensions p(i) x 1
%
% 
% objlss = objlss.setDcen(Dcen) sets the overall matrix Dcen. The matrix input
% (matrix Dcen) must have dimensions p x numIcen
% 
% ---------------------------------------------------------------------------
% INPUT
% --------------------------------------------------------------------------- 
% Dcenij = new matrix Dcenij
% 
% i = number or name of the system interested
% 
% j = number of the centralized inputs
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new Dcen matrix 
% 
%
% see also ADDCENTRALIZEDINPUT GETDCEN

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if isempty(obj.pi)
        obj.pi=obj.ni;
    end
    
    if nargin==2
        
        if obj.numICen==0
            error('SETDCEN: no centralized inputs')
        end
        
        if (size(Dcen,2)~=obj.numICen)
            error('SETDCEN: Dcen columns=%d ~= numICen=%d',size(Dcen,2),obj.numICen)
        end
        
        if size(Dcen,1)~=sum(obj.pi)
            error('SETDCEN: Dcen rows = %d ~= sum(pi)=%d',size(Dcen,1),sum(obj.pi))
        end
        
        obj.Dcen = sparse(Dcen);
        return
    end
    
    if nargin==4 %Dcen_ij between system i and centralized input j
        if j>obj.numICen
            error('SETDCEN: no centralized input %d',j)
        end
        if ischar(i)
            i=obj.name2index(i);
        end
        
        
        if isempty(obj.C)
            obj.C = sparse(eye(size(obj.A)));
            obj.D = sparse(zeros(size(obj.C,1),size(obj.B,2)));
            obj.pi = obj.ni;
        end
        
        if size(Dcen,1)~=obj.pi(i)
            error('SETDCEN Dcen rows=%d ~= pi(%d)=%d',size(Dcen,1),i,obj.pi(i))
        end
        
        if size (Dcen,2)~=1
            error('SETDCEN: Dcen rows=%d ~=1',size(Dcen,2))
        end
        
        if isempty(obj.Dcen)
            obj.Dcen = sparse(zeros(sum(obj.pi),obj.numICen));
        end
        
        obj.Dcen(sum(obj.pi(1:i-1))+1:sum(obj.pi(1:i)),j) = sparse(Dcen);
    end
    
end