function obj = setM(obj,Mij,i,j)
% SETM Sets a new matrix M in an LSS
% 
% objlss = objlss.setM(Mij,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix M (or a part of it) of the lss object objlss
%
% objlss = objlss.setM(Mij,i,j) sets the matrix Mij, i.e. the
% coupling from subsystem i to exogenous input j. The input matrix Mij 
% must have dimensions n(i) x 1
%
% 
% objlss = objlss.setM(M) sets the overall matrix M. The matrix input
% (matrix M) must have dimensions n x numExo
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Mij = new matrix Mij
% 
% i = number or name of the system interested
% 
% j = number of the exogenous signals
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new M matrix 
% 
%
% see also ADDEXOINPUT GETM

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    [Mijr, Mijc]=size(Mij);
    
    if nargin==2
        [Mr, Mc]=size(obj.M);
        if Mr==Mijr && Mc==Mijc
            obj.M = sparse(Mij);
        end
        return
    end
    
    if ischar(i)==1
        i=name2index(obj,i);
    end
    
    if  j>size(obj.M,2)
        error('SETM: no exogenous signals')
    end
    
    if Mijr~= obj.ni(i)
        error('SETM: Mij rows=%d ~= ni(&d)=%d',Mijr,i,obj.ni(i))
    end
    
    if Mijc~=1
        error('SETM: Mij Columns ~=1')
    end
    
    obj.M(sum(obj.ni(1:i-1))+1:sum(obj.ni(1:i)),j)=Mij;
end