function obj = setN(obj,Nij,i,j)
% SETN Sets a new matrix N in an LSS
% 
% objlss = objlss.setN(Nij,i,j)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the overall matrix N (or a part of it) of the lss object objlss
%
% objlss = objlss.setN(Nij,i,j) sets the matrix Nij, i.e. the
% coupling from subsystem i to exogenous input j. The input matrix Nij 
% must have dimensions p(i) x 1
%
% 
% objlss = objlss.setN(N) sets the overall matrix N. The matrix input
% (matrix N) must have dimensions p x numExo
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Nij = new matrix to Nij
% 
% i = number or name of the system interested
% 
% j = number of the exogenous signals
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss with the new N matrix
%    
%
% see also ADDEXOINPUT GETN

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    [Nijr, Nijc]=size(Nij);
    
    if nargin==2
        [Nr, Nc]=size(obj.N);
        if Nr==Nijr && Nc==Nijc
            obj.N = sparse(Nij);
        end
        return
    end
    
    if ischar(i)==1
        i=name2index(obj,i);
    end
    
    if isempty(obj.pi)
        obj.pi=obj.ni;
    end
    
    if  j>obj.numExo
        error('SETN: no exogenous signals')
    end
    
    if isempty (obj.C)
        obj.C = sparse(eye(sum(obj.ni)));
        obj.D = sparse(zeros(sum(obj.ni),sum(obj.mi)));
        obj.pi = obj.ni;
    end
    
    if Nijr~=obj.pi(i)
        error('SETN: Nij rows=%d ~= pi(%d)=%d',Nijr,i,obj.pi(i))
    end
    
    if Nijc~=1
        error('SETN: Nij Columns ~=1')
    end
    
    if isempty(obj.N)
        obj.N = zeros(sum(obj.pi),obj.numExo);
    end
    
    obj.N(sum(obj.pi(1:i-1))+1:sum(obj.pi(1:i)),j)=Nij;
end