function obj = setNameu(obj,i,name)
% SETNAMEU set the name of the inputs of the i-th subsystem
% 
% objlss = objlss.setNameu(i,name)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the name of the inputs of the i-th system. Setting the name you will 
% improve your experience, for example, with figures
% 
% USAGE:
%
% objlss = objlss.SETNAMEU(i,name)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the exogenous signal
% 
% name = cell array of string. With numbers of rows equal to numbers of
% the inputs of the i-th subsystem (i.e. m(i))
% 
% Example with m(3)=2 
% objlss = objlss.setNameu (3, {'input1';'input2'})
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss updated
%     
%
% see also PLOTU STAIRSU

% Copyright is with the following author(s):
%
% (C) 2013 
%     Fabio Sarzo, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     fabio.sarzo01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ~iscellstr(name)
        error('SETNAMEU: name must be a column cell of char in columns')
    end
    
    if ischar(i)
        i = name2index(i);
    end
    
    if i>obj.numSys
        error('SETNAMEU: System %d not exist yet',i)
    end
    
    if size(name,1)>obj.mi(i) || size(name,2)~=1
        error('SETNAMEU: insert %d x %d names, but system %d has %d input',size(name,1),size(name,2),i,obj.mi(i))
    end
    
    if isempty(obj.nameu)
        obj.nameu = cell(1,obj.numSys);
    end
    
    obj.nameu {i} = name;
    
end