function obj = setNameucen(obj,i,name)
% SETNAMEUCEN sets the name of the i-th centralized input
% 
% objlss = objlss.setNameucen(i,name)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the name for of i-th centralized input. Setting the name, will
% improve your experience, for example, with figures
% 
% USAGE:
%
% objlss = objlss.SETNAMEUCEN(i,name)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the subsystem involved
% 
% name = string
%
% objlss = objlss.setNameucen (3, 'Ucen3')
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss updated
%     
%
% see also PLOTUCEN STAIRSUCEN

% Copyright is with the following author(s):
%
% (C) 2013 
%     Fabio Sarzo, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     fabio.sarzo01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ~ischar(name)
        error('SETNAMEUCEN: name must be a string')
    end
    
    if i>obj.numICen
        error('SETNAMEUCEN: centralized input %d does not exist',i)
    end
    
    if size(name,1) ~= 1  || size(name,2)~=1
        error('SETNAMEUCEN: too many names inserted')
    end
    
    if isempty(obj.nameucen)
        obj.nameucen = cell(1,obj.numICen);
    end
    
    obj.nameucen{i} = name;
end