function obj = setNamex(obj,i,name)
% SETNAMEX sets the name of the states of the i-th subsystem
% 
%  objlss = objlss.setNamex(i,name)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set the name of the states of the i-th subsystem. Setting the name, will 
% improve your experience, for example, with figures
% 
% USAGE:
%
% objlss = objlss.SETNAMEX(i,name)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% i = number or name of the subsystem involved
% 
% name = cell array of string. With numbers of rows equal to numbers of
% the states of the i-th system (i.e. n(i))
%
% Example with n(3)=2
% objlss = objlss.setNamex (3, {'state1';'state2'})
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objlss updated
%  
%
% see also PLOTX STAIRSX

% Copyright is with the following author(s):
%
% (C) 2013 
%     Fabio Sarzo, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     fabio.sarzo01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ~iscellstr(name)
        error('SETNAMEX: name must be a column cell of char in columns')
    end
    
    if ischar(i)
        i = name2index(i);
    end
    
    if i>obj.numSys
        error('SETNAMEX: System %d not exist yet',i)
    end
    
    if size(name,1)>obj.ni(i) || size(name,2)~=1
        error('SETNAMEX: insert %d x %d names, but system %d has %d states',size(name,1),size(name,2),i,obj.ni(i))
    end
    
    if isempty(obj.namex)
        obj.namex = cell(1,obj.numSys);
    end
    
    obj.namex{i} = name;
    
end