function test = checkErrorEstimation(obj,e)
% CHECKERRORESTIMATION check if the initial error e is allowed
%
% test = checkErrorEstimation(obj,e)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Check if the value of estimation error specified in the input e is
% allowed.
% 
% USAGE: 
%  
% test = checkErrorEstimation(obj,e)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj = pnpEstimator object
%
% e = estimation error
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% test = 1 if e is an acceptable estimation error, 0 otherwise
%
%
% see also PNPESTIMATOR

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------     

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin<2
        error('CHECKERRORESTIMATION: number of input parameters')
    end
    
    test = 0;
    if any(obj.He*e-obj.Ke>1e-6)
        return;
    end
    
    dis = obj.funcins(e);
    if all(dis<=1e-6)
        test = 1;
    end
    
end