function display(est)
% DISPLAY display properties of a pnpEstimator object in the command window
% 
% est.display
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Display properties of a pnpEstimator object in the command window
%
% USAGE:
% 
% est.display
% est
%
% see also PNPESTIMATOR
 

%Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------  

    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if numel(est)==0
        fprintf('Empty Plug-and-Play estimator.\n');
        return;
    elseif numel(est) > 1
        fprintf('Array of %i Plug-and-Play estimators\n', numel(est));
        return
    end
    
    if isempty(est.A)
        fprintf('Empty Plug-and-Play estimator.\n');
        return;
    end
    
    fprintf('Plug-and-Play estimator\n');
    
    fprintf('\tInputs:\n');
    fprintf('\t\t local outputs\n');
    fprintf('\t\t local control inputs\n');
    if ~isempty(est.couplingA)
        fprintf('\t\t state estimates from parent subsystem %d\n',est.couplingA);
        if ~isempty(est.Lij)
            for i=1:length(est.pj)
                if est.pj(i)~=0
                    fprintf('\t\t outputs from parent subsystem %d\n',est.couplingA(i));
                end
            end
        end
        if any(est.mj~=0)
            for i=1:length(est.mj)
                if est.mj(i)~=0
                    fprintf('\t\t control inputs from parent subsystem %d\n',est.couplingA(i));
                end
            end
        end
    end
    if ~isempty(est.ICen)
        fprintf('\t\t centralized control input %d\n',est.ICen);
    end
    if ~isempty(est.Exo)
        fprintf('\t\t exogenous input %d\n',est.Exo);
    end
    
    
    fprintf('\tOutputs:\n');
    fprintf('\t\t local state estimates\n');
    fprintf('\t\t local output estimates\n');
    
    if ~isempty(est.ExoBounded) || (est.Ke(1)~=inf)
        fprintf('\tRobustness:\n');
    end
    if (est.Ke(1)~=inf)
        fprintf('\t\t bounded-error estimation\n');
    end
    if ~isempty(est.ExoBounded)
        fprintf('\t\t exogenous input %d\n',est.ExoBounded);
    end
    
    
end