function [ Si , obj ] = mRPIS( obj )
% MRPIS Compute set Si included in Ei as a minimal robust positively invariant set
%
% [ Si , obj ] = mRPIS( obj )
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Compute set Si included in Ei as a minimal robust positively invariant set
%  
% [ Si , obj ] = MRPIS( obj )
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj = pnpEstimator object
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% Si is a minimal robust positively invariant set
% obj is the object pnpEstimator updated with Si for future use
%
% see also PNPESTIMATOR

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    Ai   = full(obj.A);
    n    = size(Ai,1);
    Sgen = obj.Sgen(:,any(obj.Sgen~=0));
    ng   = size(Sgen,2);
    
    if isempty(obj.S)
        k    = floor(log10(1e-6)/log10(max(abs(eig(full(Ai))))));
        Amul = eye(n);
        Sg   = [  Sgen zeros(n,k*ng) ] ;
        for i = 1:k
            Amul = Amul*Ai;
            Sg(:,i*ng+1:(i+1)*ng) = Amul*Sgen;
        end
        obj.S = zonotope(zeros(n,1),Sg);
    end
    Si = obj.S;
    
    
end