function [ sys ] = pnpEstimator2ss( obj )
% PNPESTIMATOR2SS Obtain an ss object from a pnpEstimator object
%
% [ sys ] = pnpEstimator2ss( obj )
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Obtain an ss object from a pnpEstimator2ss one.
%  
% [ sys ] = PNPESTIMATOR2SS( obj )
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj = pnpEstimator object
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% sys = ss object
%
% see also PNPESTIMATOR SS

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if nargin>1
        error('PNPESTIMATOR2SS: number of input parameters')
    end
    
    sys  = ss( full(obj.A) , full(obj.B) , [ full(obj.C) ; eye(size(obj.A,1)) ] , 0 , obj.Ts );
    
    maxi = max([size(obj.A,1);size(obj.B,2);size(obj.C,1)]);
    stri = cell(maxi,1);
    for i=1:maxi
        stri{i,1} = num2str(i);
    end
    
    strx = cell(size(obj.A,1),1);
    for i=1:size(obj.A,1)
        strx{i,1} = [ 'xi_' stri{i} 'e' ];
    end
    set(sys,'StateName',strx)
    stry = cell(size(obj.A,1)+size(obj.C,1),1);
    for i=1:size(obj.C,1)
        stry{i,1} = [ 'yi_' stri{i} 'e' ];
    end
    stry(size(obj.C,1)+1:end,1) = strx;
    set(sys,'OutputName',stry)
    OutputGroup.OutputEstimate_yie = 1:size(obj.C,1) ;
    OutputGroup.StateEstimate_xie = size(obj.C,1)+1:size(obj.A,1);
    set(sys,'OutputGroup',OutputGroup)
    
    
    stru = cell(size(obj.B,2),1);
    for i=1:obj.estInputs(1)
        stru{i,1} = [ 'yi_' stri{i} ];
    end
    
    for j=1:length(obj.nj)
        for n=1:obj.nj(j)
            stru{obj.estInputs(1)+sum(obj.nj(1:j-1))+n,1} = [ 'xj' stri{obj.couplingA(j)} '_' stri{n} ];
        end
    end
    
    for j=1:length(obj.pj)
        for n=1:obj.pj(j)
            stru{sum(obj.estInputs(1:2))+sum(obj.pj(1:j-1))+n,1} = [ 'yj' stri{obj.couplingA(j)} '_' stri{n} ];
        end
    end
    
    for i=1:obj.estInputs(4)
        stru{sum(obj.estInputs(1:3))+i,1} = [ 'ui_' stri{i} ];
    end
    
    for j=1:length(obj.mj)
        for n=1:obj.mj(j)
            stru{sum(obj.estInputs(1:4))+sum(obj.mj(1:j-1))+n,1} = [ 'uj' stri{obj.couplingA(j)} '_' stri{n} ];
        end
    end
    
    for i=1:length(obj.ICen)
        stru{sum(obj.estInputs(1:5))+i,1} = [ 'ucen_' num2str(obj.ICen(i)) ];
    end
    
    for i=1:length(obj.Exo)
        stru{sum(obj.estInputs(1:6))+i,1} = [ 'd_' num2str(obj.Exo(i)) ];
    end
    set(sys,'InputName',stru)
    
    InputGroup.Measurement_yi   = 1:obj.estInputs(1) ;
    InputGroup.StateEstimate_xj = obj.estInputs(1)+1:obj.estInputs(2) ;
    InputGroup.Measurement_yj   = obj.estInputs(2)+1:obj.estInputs(3) ;
    InputGroup.KnownInput_ui    = obj.estInputs(3)+1:obj.estInputs(4) ;
    InputGroup.KnownInput_uj    = obj.estInputs(4)+1:obj.estInputs(5) ;
    InputGroup.KnownInput_ucen  = obj.estInputs(5)+1:obj.estInputs(6) ;
    InputGroup.KnownInput_d     = obj.estInputs(6)+1:obj.estInputs(7) ;
    set(sys,'InputGroup',InputGroup)
    
end