function [ sup, info, e ] = supportFunctionS(obj,c,options)
% SUPPORTFUNCTIONS Support function of set S evaluated in the point c
%
% [ sup , info , e ] = supportFunctionS(obj,c,options)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% The support function of set computed in c is
%
% sup = max_{e\in S} (c'*e)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% obj - pnpEstimator object
% c   - column vector of the same dimension of S
% options - sdpsettings object
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% sup value of the support function
% x is the solution of the LP problem
% info from solvesdp (see yalmip)
%
% see also PNPESTIMATOR

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    if nargin<2 || nargin>3
        error('CHECKERRORESTIMATION: number of input parameters')
    end
    
    if nargin~=3
        options = sdpsettings;
    end
    
    if all(obj.Ke==inf)
        sup       = inf;
        info.info = 'There is No Bounded Estimation';
        e         = inf;
        return
    end
    
    e    = sdpvar(size(obj.A,1),1);
    dis  = obj.funcins(e);
    CONS = [ dis<=zeros(size(dis,1),1) ; obj.He*e<=obj.Ke ];
    
    info = solvesdp(CONS,-c'*e,options);
    
    if info.problem~=0
        error('CHECKERRORESTIMATION: solver error')
    end
    
    e   = double(e);
    sup = c'*e;
    
end