function display(ctrl)
% DISPLAY display properties of a pnpctrl object in the command window
% 
% ctrl.display
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Display properties of a pnpctrl object in the command window
%
% USAGE:
% 
% ctrl.display
% ctrl
%
% see also PNPCTRL
 

%Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------  

    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if numel(ctrl)==0
        fprintf('Empty unconstrained Plug-and-Play controller.\n');
        return;
    elseif numel(ctrl) > 1
        fprintf('Array of %i unconstrained Plug-and-Play controllers\n', numel(ctrl));
        return
    end
    
    if isempty(ctrl.A)
        fprintf('Empty unconstrained Plug-and-Play controller.\n');
        return;
    end
    
    fprintf('Unconstrained Plug-and-Play controller\n');
    
    fprintf('\tInputs:\n');
    fprintf('\t\t local states\n');
    if ~isempty(ctrl.Nij)
        fprintf('\t\t states from parent subsystem %d\n',ctrl.Nij);
    end
    
    fprintf('\tOutputs:\n');
    fprintf('\t\t local control inputs\n');
    
end