function subss = addCentralizedInput(subss,Bcen,Dcen)
% ADDCENTRALIZEDINPUT defines a new centralized input
%
% objsubss=addCentralizedInput(objsubss,Bcen,Dcen) 
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Function used to define Bcen and Dcen matrices 
% 
% objsubss = objsubss.ADDCENTRALIZEDINPUT(Bcen,Dcen)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Bcen and Dcen =  matrix with opportune dimensions
% 
% objsubss = object of subss type
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objsubss with Bcen and Dcen setted
% 
%
% see also: ADDCENTRALIZEDINPUTCONSTRAINT 

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if size(Bcen,1)~=size(subss.A,1)
        error('ADDCENTRALIZEDINPUT: Bcen rows=%d ~= sum(ni)=%d',size(Bcen,1),sum(subss.ni))
    end
    
    
    subss.Bcen = [ subss.Bcen sparse(Bcen) ];
    tmp        = max(subss.ICen);
    if ~isempty(tmp)
        subss.ICen = [ subss.ICen tmp + (1:size(Bcen,2)) ];
    else
        subss.ICen = 1 : size(Bcen,2);
    end
    
    if ~isempty(subss.Hcen)
        subss.Hcen = sparse([ subss.Hcen zeros(size(subss.Hcen,1),size(Bcen,2)) ]);
    end
    
    if nargin<=2
        return
    end    
    
    if ~isempty(Dcen)
        
        if isempty(subss.C)
            p = size(subss.A,1);
        else
            p = size(subss.C,1);
        end
        
        if size(Dcen,1)~=p
            error('ADDCENTRALIZEDINPUT: Dcen rows=%d ~= C rows=%d',size(Dcen,1),p)
        end
        
        if size(Bcen,2)~=size(Dcen,2)
            error('ADDCENTRALIZEDINPUT: Bcen e Dcen must have same number of columns.')
        end
        subss.Dcen = sparse([ subss.Dcen Dcen ]);
        
        if isempty(subss.C)
            subss.C = sparse(eye(size(subss.A)));
            subss.D = sparse(zeros(size(subss.C,1),size(subss.B,2)));
        end   
        
    end
    
end