function subss = addExoInput(subss,M,N)
% ADDEXOINPUT adds an exogenous input to a subsystem
%
% objsubss = addExoInput(objsubss,M,N) 
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Define matrices M and N for exogenous signals acting on subsystem subss
%
% objsubss = objsubss.ADDEXOINPUT(M,N) 
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% M and N are matrices of suitable dimension
% 
% objsubss = object of subss type
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% subss object updated with M and N
%    
%
% see also ADDEXOCONSTRAINT 
    
% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if size(M,1)~=size(subss.A,1)
        error('ADDEXOINPUT: M rows=%d ~= sum(ni)=%d',size(M,1),sum(subss.ni))
    end
    
    subss.M   = sparse([ subss.M M ]);
    tmp       = max(subss.Exo);
    if ~isempty(tmp)
        subss.Exo = [ subss.Exo tmp + (1:size(M,2)) ];
    else
        subss.Exo = 1 : size(M,2);
    end
    
    if ~isempty(subss.Hd)
        subss.Hd = sparse([ subss.Hd zeros(size(subss.Hd,1),size(M,2)) ]);
    end
    
    if nargin<=2
        return
    end
    
    if ~isempty(N)
        if isempty(subss.C)
            p = size(subss.A,1);
        else
            p = size(subss.C,1);
        end
        
        if size(N,1)~=p
            error('ADDEXOINPUT: N rows=%d ~= C rows=%d',size(N,1),p)
        end
        
        if size(M,2)~=size(N,2)
            error('ADDEXOINPUT: M e N must have same number of columns.')
        end
        subss.N = sparse([ subss.N N ]);
        
        if isempty(subss.C)
            subss.C = sparse(eye(size(subss.A)));
            subss.D = sparse(zeros(size(subss.C,1),size(subss.B,2)));
        end
    end 
end