function objsubss = addInputConstraint( objsubss,H,K )
% ADDINPUTCONSTRAINT defines polyhedral constraints on inputs of a subsystem
%
% objsubss = addInputConstraint (objsubss,H,K)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Constraints are in this form: H*u<=K
%  
% objsubss = objsubss.ADDINPUTCONSTRAINT(H,K)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Matrices H and K of suitable dimension
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% subss object with updated matrices Hu and Ku
% 
%
% see also ADDSTATECONSTRAINT ADDOUTCONSTRAINT
   
% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if size(H,1)~=size(K,1)
        error('ADDINPUTCONSTRAINT: H rows=%d ~= K rows=%d',size(H,1),size(K,1))
    end
    
    if size(H,2)~=size(objsubss.B,2)
        error('ADDINPUTCONSTRAINT: H columns=%d ~= B columns=%d', size(H,2),size(objsubss.B,2))
    end
    
    objsubss.Hu=H;
    objsubss.Ku=K;
end