function objsubss = addOutConstraint( objsubss,H,K )
% ADDOUTCONSTRAINT defines polyhedral constraints on subsystem outputs
%
% objsubss = addOutConstraint (objsubss,H,K)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Constraints are in this form: H*y<=K
%
% objsubss = objsubss.ADDOUTCONSTRAINT(H,K)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Matrices Hy and Ky of suitable dimension
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% subss object with updated matrices Hy and Ky
% 
%
% see also ADDSTATECONSTRAINT ADDINPUTCONSTRAINT 

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if isempty(objsubss.C) && isempty(objsubss.D)
        warning('MATLAB:paramAmbiguous','ADDOUTCONSTRAINT: state-feedback system y = x: output constraints are considered as state constraints')
        objsubss = objsubss.addStateConstraint(sysindex,H,K);
        return
    end
    
    if size(H,1)~=size(K,1)
        error('ADDOUTCONSTRAINT: H rows=%d ~= K rows=%d',size(H,1),size(K,1))
    end
    
    if size(H,2)~=size(objsubss.C,1)
        error('ADDOUTCONSTRAINT: H columns=%d ~= p=%d', size(H,2),size(objsubss.C,1))
    end
    
    objsubss.Hy=H;
    objsubss.Ky=K;
    
end