function display(objsubss)
% DISPLAY display properties of a subss object in the command window
% 
% objsubss.display
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Display properties of an subss object in the command window
%
% USAGE:
% 
% objsubss.display
% objsubss
%
% see also SUBSS
 

%Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it, giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------  

 
    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
 
    if numel(objsubss)==0
        fprintf('Empty subsystem.\n');
        return;
    elseif numel(objsubss) > 1
        fprintf('Array of %i subsystems\n', numel(objsubss));
        return
    end
    
    if isempty(objsubss.A)
        fprintf('Empty subsystem.\n');
        return;
    end
    
    if objsubss.Ts==-1
        fprintf('\tDiscrete-time SUBSS\n');
    elseif objsubss.Ts>0
        fprintf('\tContinuous-time SUBSS, discretize with sample time: %f\n',objsubss.Ts);
    else
        fprintf('\tContinuous-time SUBSS\n');
    end
    
    fprintf('\tVariables:\n');
    if isempty(objsubss.C)
        fprintf('\t\t%d states; state-feedback\n',size(objsubss.A,1));
    else
        fprintf('\t\t%d states\n',size(objsubss.A,1));
    end
    if size(objsubss.B,2)~=0
        fprintf('\t\t%d local inputs\n',size(objsubss.B,2));
    end
    if ~isempty(objsubss.C)
        fprintf('\t\t%d outputs\n',size(objsubss.C,1));
    end
    if ~isempty(objsubss.ICen) && any(objsubss.ICen~=0)
        fprintf('\t\t%d centralized inputs (see .ICen)\n',numel(objsubss.ICen));
    end
    if ~isempty(objsubss.Exo) && any(objsubss.Exo~=0)
        fprintf('\t\t%d exogenous inputs (see .Exo)\n',numel(objsubss.Exo));
    end
    
    if ~isempty(objsubss.Hx) || ~isempty(objsubss.Hu) || ~isempty(objsubss.Hdeltau) || ~isempty(objsubss.Hy) || ~isempty(objsubss.Hd) || ~isempty(objsubss.Hcen) || ~isempty(objsubss.He)
        fprintf('\tConstraints:\n');
        if ~isempty(objsubss.Hx)
            fprintf('\t\t%d state constraints\n',size(objsubss.Hx,1));
        end
        if ~isempty(objsubss.Hu)
            fprintf('\t\t%d input constraints\n',size(objsubss.Hu,1));
        end
        if ~isempty(objsubss.Hdeltau)
            fprintf('\t\t%d input rate constraints\n',size(objsubss.Hdeltau,1));
        end
        if ~isempty(objsubss.C)
            if ~isempty(objsubss.Hy)
                fprintf('\t\t%d output constraints\n',size(objsubss.Hy,1));
            end
        end
        if ~isempty(objsubss.Hcen)
            fprintf('\t\t%d centralized inputs constraints\n',size(objsubss.Hcen,1));
        end
        if ~isempty(objsubss.Hd)
            fprintf('\t\t%d exogenous inputs constraints\n',size(objsubss.Hd,1));
        end
        if ~isempty(objsubss.He)
            fprintf('\t\t%d error state estimation constrained constraints\n',size(objsubss.He,1));
        end
    end
    
    if ~isempty(objsubss.couplingA) || ~isempty(objsubss.couplingB) || ~isempty(objsubss.couplingC) || ~isempty(objsubss.couplingD)
        fprintf('\tCoupling:\n');
        if ~isempty(objsubss.couplingA)
            fprintf('\t\tStates of %d subsystems act on SUBSS states\n',numel(objsubss.couplingA));
        end
        if ~isempty(objsubss.couplingB)
            fprintf('\t\tInputs of %d subsystems act on SUBSS states\n',numel(objsubss.couplingB));
        end
        if ~isempty(objsubss.couplingC)
            fprintf('\t\tStates of %d subsystems act on SUBSS outputs\n',numel(objsubss.couplingC));
        end
        if ~isempty(objsubss.couplingD)
            fprintf('\t\tInputs of %d subsystems act on SUBSS outputs\n',numel(objsubss.couplingD));
        end        
    end
    
    
end