function [Hcen,Kcen] = doubleCenInputConstraint( objsubss )
% DOUBLECENINPUTCONSTRAINT returns Hcen and Kcen matrices defining the Polyhedron Ucen
% 
% [Hcen,Kcen] = doubleCenInputConstraint(objsubss)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return Hcen and Kcen matrices or the Polyhedron Ucen

% [Hcen,Kcen] = objsubss.DOUBLEINPUTCONSTRAINT
% 
% USAGE:
% Ucen = objsubss.doubleCenInputConstraint, return only the Polyhedron
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% subss object
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% [Hcen, Kcen] Hcen and Kcen matrices defining the Polyhedron Ucen
% = { Hcen*ucen<=Kcen }
% 
% [Ucen] Polyhedron object [1]
% 
%
% see also ADDCENTRALIZEDINPUTCONSTRAINT 
%
% [1] M. Herceg, M. Kvasnica, C. N. Jones, and M. Morari, "Multi-Parametric 
% Toolbox 3.0," in Proceedings of the 12th European Control Conference, 
% 2013, pp. 502-510, http://control.ee.ethz.ch/~mpt
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01@universitadipavia.it, stefano.riverso@unipv.it, 
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if isempty (objsubss.Hcen)
        Hcen = [];
        Kcen = [];
    else
        Hcen = objsubss.Hcen;
        Kcen = objsubss.Kcen;
    end
    
    if nargout == 1 || nargout==0
        Hcen = Polyhedron(full(Hcen),full(Kcen));
    end
    
end