function [He,Ke] = doubleErrorEstimationConstraint( objsubss )
% DOUBLEERRORESTIMATIONCONSTRAINT returns He and Ke matrices defining the Polyhedron E
% 
% [He,Ke] = doubleErrorEstimationConstraint(objsubss)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return He and Ke matrices or the Polyhedron E. 
% e is defined as x-xc, where xc is the state estimation.
% 
% [He,Ke] = objsubss.DOUBLEERRORESTIMATIONCONSTRAINT
%
% USAGE: 
% E = objsubss.doubleErrorEstimationConstraint
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% subss object
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% [He, Ke] He and Ke matrices defining the Polyhedron E
% = { He*e<=Ke }
% 
% [E] Polyhedron object [1]
% 
%
% see also ADDERRORESTIMATIONCONSTRAINT
%
% [1] M. Herceg, M. Kvasnica, C. N. Jones, and M. Morari, "Multi-Parametric 
% Toolbox 3.0," in Proceedings of the 12th European Control Conference, 
% 2013, pp. 502-510, http://control.ee.ethz.ch/~mpt
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01@universitadipavia.it, stefano.riverso@unipv.it, 
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if isempty (objsubss.He)
        He = [];
        Ke = [];
    else
        He = objsubss.He;
        Ke = objsubss.Ke;
    end
    
    if nargout == 1 || nargout==0
        He = Polyhedron(full(He),full(Ke));
    end
    
end