function [Hd,Kd] = doubleExoConstraint( objsubss )
% DOUBLEEXOCONSTRAINT returns Hd and Kd matrices defining the Polyhedron D
% 
% [Hd,Kd] = doubleStateConstraint(objsubss)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Return Hd and Kd matrices or the Polyhedron D
% 
% [Hd,Kd] = objsubss.DOUBLESTATECONSTRAINT
%
% USAGE: 
% D = objsubss.doubleStateConstraint
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% subss object
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% [Hd, Kd] Hd and Kd matrices defining the Polyhedron D
% = { Hd*d<=Kd }
% 
% [D] Polyhedron object [1]
% 
%
% see also ADDEXOCONSTRAINT
%
% [1] M. Herceg, M. Kvasnica, C. N. Jones, and M. Morari, "Multi-Parametric 
% Toolbox 3.0," in Proceedings of the 12th European Control Conference, 
% 2013, pp. 502-510, http://control.ee.ethz.ch/~mpt
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01@universitadipavia.it, stefano.riverso@unipv.it, 
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if isempty (objsubss.Hd)
        Hd = [];
        Kd = [];
    else
        Hd = objsubss.Hd;
        Kd = objsubss.Kd;
    end
    
    if nargout == 1 || nargout==0
        Hd = Polyhedron(full(Hd),full(Kd));
    end
    
end