function [ N ] = getN( subss )
% GETN gets the matrix N of exogenous signals acting on a subsystem
% 
% N = getN(objsubss)
% ---------------------------------------------------------------------------
% DESCRIPTION
% --------------------------------------------------------------------------- 
% Return N matrix 
%
% N = subss.GETN
% ---------------------------------------------------------------------------
% INPUT
% --------------------------------------------------------------------------- 
% subss object
%
% ---------------------------------------------------------------------------
% OUTPUT
% --------------------------------------------------------------------------- 
% N desired dynamic matrix
%
%
% see also SETN

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if isempty(subss.N)
        if isempty(subss.M)
            N = [];
        else
            if isempty(subss.C)
                N = sparse(zeros(size(subss.A,1),size(subss.M,2)));
            else
                N = sparse(zeros(size(subss.C,1),size(subss.M,2)));
            end
        end
    else
        N = subss.N;
    end
end