function obj = setBcen( obj,Bcen )
% SETBCEN sets a new matrix Bcen for a subsystem
% 
% objsubss = objsubss.setBcen(Bcen)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set a new Bcen matrix with the same dimensions of the previous matrix
% Bcen.
% 
% objsubss = objsubss.SETBCEN(Bcen)
% 
% ---------------------------------------------------------------------------
% INPUT
% --------------------------------------------------------------------------- 
% Bcen = new matrix Bcen
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------  
% objsubss with new Bcen matrix 
% 
%
% see also GETBCEN


% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if size(obj.Bcen,1)==size(Bcen,1) && size(obj.Bcen,2)==size(Bcen,2)
        obj.Bcen = Bcen;
    else
        error('SETBCEN: Bcen must have same numbers of rows and columns of the previous Bcen (%d x %d)',size(obj.Bcen,1),size(obj.Bcen,2))
    end
    
end