function obj = setC(obj,C)
% SETC Sets a new matrix C for a subsystem
% 
% objsubss = objsubss.setC(C)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set a new C matrix, with the same dimensions of the previous matrix C.
% 
% objsubss = objsubss.SETC(C)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------  
% C = new matrix C
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------  
% objsubss with new C matrix
% 
%
% see also GETC

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if size(obj.C,1)==size(C,1) && size(obj.C,2)==size(C,2)
        obj.C = C;
    else
        error('SETC: C must have same numbers of rows and columns  of the previous C (%d x %d)',size(obj.C,1),size(obj.C,2))
    end
    
end