function objsubss = setCoupling(objsubss,objlss,i)
% SETCOUPLING Set a coupling among current subsystem and subsystem of a large-scale system
%
% objsubss = setCoupling(objsubss,objlss,i)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Find all coupling among subsystem i and others subsystems j in the lss.
% Matrices Aij, Bij, Cij, Dij are setted in the subss object.
% 
% objsubss = objsubss.SETCOUPLING(objlss,i)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% objsubss : object of subss type
% objlss : object of lss class
% i : index of the current subsystem in the large-scale system
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% objsubss : object of subss type
%
%
% see also LSS 

% Copyright is with the following author(s):
%
% (C) 2012
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01@universitadipavia.it, stefano.riverso@unipv.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
%
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the
%          Free Software Foundation, Inc.,
%          59 Temple Place, Suite 330,
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    for k=1:objlss.numSys
        if k~=i
            if objlss.couplingmatrix(i,k)
                [a,b,c,d] = objlss.isCoupled(i,k);
                objsubss.nj(end+1) = 0;
                objsubss.mj(end+1) = 0;
                if a
                    objsubss.Aij=[objsubss.Aij,objlss.getA(i,k)];
                    objsubss.couplingA(1,end+1)=k;
                    objsubss.nj(end)=objlss.ni(k);
                end
                
                if b
                    objsubss.Bij=[objsubss.Bij,objlss.getB(i,k)];
                    objsubss.couplingB(1,end+1)=k;
                    objsubss.nj(end)=objlss.ni(k);
                    objsubss.mj(end)=objlss.mi(k);
                end
                
                if c
                    objsubss.Cij=[objsubss.Cij,objlss.getC(i,k)];
                    objsubss.couplingC(1,end+1)=k;
                    objsubss.nj(end)=objlss.ni(k);
                end
                
                if d
                    objsubss.Dij=[objsubss.Dij,objlss.getD(i,k)];
                    objsubss.couplingD(1,end+1)=k;
                    objsubss.mj(end)=objlss.mi(k);
                end
            end
        end
    end
    
    if isempty(objlss.C)
        pi = objlss.ni;
    else
        pi = objlss.pi;
    end
    
    if isempty(objlss.N)
        N  = sparse(zeros(sum(pi),objlss.numExo));
    else
        N  = objlss.getN;
    end
    
    cont = 1;
    for k=1:objlss.numExo
        if any(objlss.M(sum(objlss.ni(1:i-1))+1:sum(objlss.ni(1:i)),k)~=0) || any(N(sum(pi(1:i-1))+1:sum(pi(1:i)),k)~=0)
            objsubss=objsubss.addExoInput(objlss.M(sum(objlss.ni(1:i-1))+1:sum(objlss.ni(1:i)),k),N(sum(pi(1:i-1))+1:sum(pi(1:i)),k));
            objsubss.Exo(1,cont) = k;
            cont = cont + 1;
        end
    end
    
    if isempty(objlss.Dcen)
        Dcen  = sparse(zeros(sum(pi),objlss.numICen));
    else
        Dcen  = objlss.getDcen;
    end
    
    cont = 1;
    for k=1:objlss.numICen
        if any(objlss.Bcen(sum(objlss.ni(1:i-1))+1:sum(objlss.ni(1:i)),k)~=0) || any(Dcen(sum(pi(1:i-1))+1:sum(pi(1:i)),k)~=0)
            objsubss = objsubss.addCentralizedInput(objlss.Bcen(sum(objlss.ni(1:i-1))+1:sum(objlss.ni(1:i)),k),Dcen(sum(pi(1:i-1))+1:sum(pi(1:i)),k));
            objsubss.ICen(1,cont) = k;
            cont = cont + 1;
        end
    end
    
    
    if isequal(objsubss.C,eye(size(objsubss.A,1),size(objsubss.A,2)))
        objsubss.C = [];
    end
    
    if all(all(objsubss.D==0))
        objsubss.D = [];
    end
    
    if all(all(objsubss.N==0))
        objsubss.N = [];
    end
    
    if all(all(objsubss.Dcen==0))
        objsubss.Dcen = [];
    end
    
    
end