function obj = setD(obj,D)
% SETD Set a new matrix D for a subsystem
% 
% objsubss = objsubss.setD(D)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set a new D matrix with the same dimensions of the previous matrix D.
% 
% objsubss = objsubss.SETD(D)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------  
% D = new matrix D
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------  
% objsubss with new D matrix 
%
%
% see also GETD 

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if size(obj.D,1)==size(D,1) && size(obj.D,2)==size(D,2)
        obj.D = D;
        if isempty(obj.C)
            obj.C = eye(size(obj.A));
        end
    else
        error('SETD: D must have same numbers of rows and columns of the previous D (%dx%d)',size(obj.getD,1),size(obj.getD,2))
    end
    
end