function obj = setN(obj,N)
% SETN sets a new matrix N for a subsystem
% 
% objsubss = objsubss.setN(N)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Set a new N matrix with the same dimensions of the previous matrix N.
% 
% objlss = objlss.SETN(N)
% 
% ---------------------------------------------------------------------------
% INPUT
% --------------------------------------------------------------------------- 
% N = new matrix N
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------  
% objsubss with new N matrix
% 
%
% see also SETN

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if size(obj.N,1)==size(N,1) && size(obj.N,2)==size(N,2)
        obj.N = N;
        if isempty(obj.C)
            obj.C = eye(size(obj.A));
        end
        
        if isempty(obj.D)
            obj.D = zeros(size(obj.A,1), size(obj.B,2));
        end
    else
        error('SETN: N must have same numbers of rows and columns of the previous N (%d x %d)',size(obj.N,1),size(obj.N,2))
    end
end