function Zn = bisect(Z)
% BISECT Bisection of zonotope Z
%
% Zn = bisect(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Bisection of zonotope Z
%
%   Zn = BISECT(Z) returns the split of a zonotope along the biggest
%   generator.
%
% USAGE:
%   Zn = BISECT(Z)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Zonotope Z
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% Zn - split of zonotope Z along the biggest generator into a zonotope array 
%
% see also SPLIT

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if ~isa(Z,'zonotope')
        error('BISECTION: Input argument must be a zonotope!');
    end
    
    if length(Z)~=1
        error('BISECTION: This function does not work with zonotope arrays!');
    end
    
    % call split with default options
    Zn = split(Z);
    
end