function BB = bounding_box(Z)
% BOUNDING_BOX Compute a zonotope bounding box for a given zonotope
%
% BB = bounding_box(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Zonotope bounding box BB for a given zonotope Z
%
%   BB = BOUNDING_BOX(Z) returns a zonotope bounding box for a given
%   zonotope or zonotope array
%
% USAGE:
%   BB = bounding_box(Z)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z - Zonotope or zonotope array
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% BB - Zonotope containing zonotope Z or all zonotope in a zonotope array Z
%
% see also ZONOTOPE

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if ~isa(Z,'zonotope')
        error('BOUNDING_BOX: Input argument must be a zonotope!');
    end
    
    lenZ = length(Z);
    
    if lenZ==1
        G  = zeros(size(Z.G,1),size(Z.G,1));
        for i=1:size(Z.G,1)
            G(i,i)=sum(abs(Z.G(i,:)));
        end
        BB = zonotope(Z.p,G);
    else
        V = [];
        for j=1:lenZ
            G = zeros(size(Z(j).G,1),size(Z(j).G,1));
            for i=1:size(Z(j).G,1)
                G(i,i) = sum(abs(Z(j).G(i,:)));
            end
            D = diag(G)';
            V = [ V ; [ Z(j).p'+D ; Z(j).p'-D ] ];
        end
        maxV = max(V);
        minV = min(V);
        BB   = zonotope(((minV+maxV)/2)',diag((maxV-minV)/2));
    end
end