function Z = computeHRep(Z)
% COMPUTEHREP Compute H-rep of a zonotope
%
% Z = computeHRep(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Compute H-Rep of a zonotope
%
% Z = Z.COMPUTEHREP;
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z   - Zonotope
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% Z updated
%
% see also ZONOTOPE COMPUTEVREP

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if ~isa(Z,'zonotope')
        error('COMPUTEHREP: Input argument must be a zonotope!');
    end
    
    if length(Z)~=1
        for i=1:length(Z)
            Z(i) = Z(i).computeHRep;
        end
        return
    end
    
    if Z.hasHRep
        return
    end
    
    if Z.hasVRep
        Z = computeHRep@Polyhedron(Z);
        return
    end
    
    Z = Z.computeVRep;
    if Z.Dim>0
        Z = Z.computeHRep;
    end
end