function Z = computeVRep(Z)
% COMPUTEVREP Compute V-rep of a zonotope
%
% vertices = computeVRep(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Compute vertices of a zonotope from its generators
%
% Z = Z.COMPUTEVREP;
%   
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z zonotope
%  
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% Z zonotope updated
% 
% see also ZONOTOPE EXTREME

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------
    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if length(Z)~=1
        for i=1:length(Z)
            Z(i) = Z(i).computeVRep;
        end
        return
    end
    
    if Z.hasVRep
        return
    end
    
    G            = Z.G;
    [ nx, ngen ] = size(G);
    tmp.A        = [eye(ngen);-eye(ngen)];
    tmp.B        = ones(2*ngen,1);
    B            = cddmex('extreme',tmp);
    B            = B.V;
    B            = reshape(repmat(B,1,nx)',ngen,2^ngen*nx)';
    G            = repmat(G,2^ngen,1).*B;
    G            = sum(G,2);
    vertices     = reshape(G,nx,2^ngen)';
    if Z.Dim>0
        vertices = repmat(Z.p',size(vertices,1),1)+vertices;
        Z        = zonotope(Z.p,Z.G,Polyhedron(vertices));
    else
        Z        = zonotope;
    end
    
end