function sys = display(Z)
% DISPLAY Displays details about the given zonotope
%
% sys = display(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Displays details of the given ZONOTOPE object.
% 
% This method is executed automatically if one types:
%   >> Z
% without the semicolumn (;) at the end
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z    - Zonotope
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% sys  - String containing the information
%
% see also ZONOTOPE
%

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    sys = [];
    
    if length(Z)~=1
        disp(['Array of ' num2str(length(Z)) ' zonotope.'])
        return
    end
    
    if Z.hasHRep || Z.hasVRep
        display@Polyhedron(Z)
    end
    
    fprintf('\n');
    
    sub_display(Z,'');
    
    return
    
end


%---------------------------------------------------------
function sub_display(Z,str)
    p = Z.p;
    G = Z.G;

    if isempty(G)
        disp([str 'Empty zonotope in R^1']);
        return
    end

    nx = size(G,1);
    str = ['Zonotope in R^' num2str(nx)];
    disp(str);

    Q.p      = p;
    Q.G      = G;


    % display the structure
    disp(struct(Q));

    if size(G,1)<=10 && size(G,2)<=5,
        % prepare display of p+G[-1 1]^m
        % only if # of generators is less than 5 and dimension is smaller than
        % 10
        lb=repmat('[',size(G,1),1);
        rb=repmat(']',size(G,1),1);
        sp=repmat(' ',size(G,1),1);
        xs=sp;
        le=[sp sp sp sp sp];
        la=[sp sp sp sp];
        xs(floor(size(G,1)/2)+1,:)='+';
        le(floor(size(G,1)/2)+1,:)='||d||';
        la(floor(size(G,1)/2)+1,:)='z = ';
        disp([la lb num2str(p) rb sp xs sp lb num2str(G) rb sp le])
    end
    fprintf('\n');
    end