function status = eq(Z,Q)
% EQ Checks if two zonotopes are equal
%
% status = eq(Z,Q)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% STATUS = EQ(Z,Q) returns TRUE (1) if Z==Q
%
% USAGE:
%   Z==Q
%   eq(Z,Q)
%
%
% NOTE: If Z and Q are empty zonotopes, returns 1 (true)
%       If one of them is empty and second one is not, returns 0 (false)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z                - Zonotope or zonotope array
% Q                - Zonotope or zonotope array
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% status    - Logical statement (1 if Z==Q, 0 otherwise)
%
% see also NE, LE, GE
%

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    global MPTOPTIONS
    if isempty(MPTOPTIONS)
        MPTOPTIONS = mptopt;
    end
    
    if ~isa(Z, 'zonotope') || ~isa(Q, 'zonotope')
        error('EQ: Argument MUST be a zonotope object');
    end
    
    status = true;
    for i=1:length(Z)
        for j=1:length(Q)
            if Z(i).Dim~=Q(j).Dim
                error('EQ: Only zonotopes of equal dimensionality can be compared');
            end
            status = all((Z(i).p-Q(j).p)<=MPTOPTIONS.abs_tol) && all(all((Z(i).G-Q(j).G)<=MPTOPTIONS.abs_tol));
            if status==false
                return
            end
        end
    end
end