function sup = extreme(Z,c)
% EXTREME  Compute extremal point of a zonotope in a given direction. 
%
% sup = extreme(Z,c)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Z.extreme(c) solves the following problem: 
%
% sup = max_{z\in Z} (c'*z)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z   - Zonotope
% c   - Direction, column vector of dimension as Z
%
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% sup - Support of c in Z.
%
% see also ZONOTOPE

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
%
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the
%          Free Software Foundation, Inc.,
%          59 Temple Place, Suite 330,
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if nargin<2
        error('EXTREME: 2 parameters for extreme(Z,c). See help extreme')
    end
    if ~isa(Z,'zonotope')
        error('EXTREME: Z is not a zonotope')
    end
    if ~isa(c,'double')
        error('EXTREME: c is not a double vector')
    end 
    
    sup = zeros(length(Z),1);    
    
    for i=1:length(Z)
        if Z(i).Dim~=size(c,1)
            error('EXTREME: dimension of Z and c are incompatible');
        end
        sup(i) = norm(Z(i).G'*c,1)+c'*Z(i).p;
    end
end