function [ status, Z, Q ] = le(Z,Q)
% LE Checks if zonotope Z is a subset of zonotope Q
%
% [ status Z Q ] = le(Z,Q)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% STATUS = LE(Z,Q) returns TRUE (1) if Z<=Q (i.e. Z is a subset of Q)
%
%   Since the H-representation of the zonotope is needed, the function LE
%   for Polyhedron is executed.
%
% USAGE:
%   Z <= Q
%   le(Z,Q)
%   [ status Z Q ] = le(Z,Q)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z                - Zonotope
% Q                - Zonotope
%
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% status        - Logical statement (true if Z<=Q, false otherwise)
% Z             - Zonotope updated with H-representation and V-representation
% Q             - Zonotope updated with H-representation and V-representation
%
% see also GE, EQ, NE, LT, GT
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if ~isa(Z, 'zonotope') || ~isa(Q, 'zonotope')
        error('LE: Argument MUST be a zonotope object');
    end
    
    for i=1:length(Z)
        Z(i) = Z(i).computeHRep;
    end
    
    for i=1:length(Q)
        Q(i) = Q(i).computeHRep;
    end
    
    status = le@Polyhedron(Z,Q);

end