function [ R, Z, Q ] = mldivide(Z,Q)
% MLDIVIDE Set difference
%
% Set difference
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Computes set difference between Z and Q
%
%   Since the H-representation of the zonotope is needed, the function
%   MLDIVIDE for Polyhedron is executed.
%
% USAGE:
%   R=Z\Q
%   R=mldivide(Z,Q)
%   [ R Z Q ] = mldivide(Z,Q)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z                  - Zonotope or zonotope array
% Q                  - Zonotope or zonotope array
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% R     - polytope (or polytope array) describing the set difference
% Z     - Zonotope updated with H-representation and V-representation
% Q     - Zonotope updated with H-representation and V-representation
%
% see also MINUS
%


% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------
    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if ~isa(Z,'zonotope') && ~isa(Q,'zonotope')
        error('MLDIVIDE: input arguments MUST be zonotopes!');
    end
    
    Z = Z.computeHRep;
    Q = Q.computeHRep;
    
    Zp = zonotope2Polyhedron(Z);
    Qp = zonotope2Polyhedron(Q);
    
    R = mldivide@Polyhedron(Zp,Qp);
end