function status = ne(Z,Q)
% NE Checks if zonotope Z is not equal to zonotope
%
% status = ne(Z,Q)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% STATUS = NE(Z,Q) returns TRUE (1) if Z~=Q
%
% USAGE:
%   Z~=Q
%   eq(Z,Q)
%
% NOTE:
%  if Z and/or Q are arrays of zonotopes, STATUS is a 
%  matrix(vector) of statements
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z                - Zonotope
% Q                - Zonotope
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% status        - Logical statement
%
% see also EQ, LE, GE, LT, GT
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ~isa(Z, 'zonotope') || ~isa(Q, 'zonotope')
        error('NE: Argument MUST be a zonotope object');
    end
    
    status = ~(Z==Q);
end