function ng = ngenerator(Z)
% NGENERATOR Returns number of generators of the given zonotope
%
% ng = ngenerator(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Returns number of generators of the given zonotope
% Z = { z | z=p+Gd , ||d||inf<=1 }, i.e. the number of columns of matrix G
% in the minimal representation of Z
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z   - Zonotope
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% ng  - number of generators of the given zonotope (or zonotope array)
%
% see also DIMENSION
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------
    
    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    % number of constraints is just number of rows of the H matrix
    nZ = length(Z);
    ng = zeros(length(Z),1);
    if nZ>0,
        % return total number of facets for the whole polytope array
        for ip = 1:nZ
            ng(ip) = size(Z(ip).G,2);
        end
    elseif isempty(Z.G)
        ng = [];
    else
        ng = size(Z.G,2);
    end
end