function R = uminus(Z)
% UMINUS Unary minus for a zonotope
%
% R = uminus(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
%
% Mirrors a zonotope around the origin
%
% USAGE:
%   R = -Z
%   R = uminus(Z)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z   - zonotope
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% R   - zonotope mirrored around the origin
%
% see also UPLUS
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ~isa(Z, 'zonotope')
        error('UMINUS: Argument MUST be a zonotope object');
    end
    
    R(size(Z)) = zonotope;
    
    for i=1:length(Z)
        tmp  = Polyhedron('H',full([-Z(i).A Z(i).b]),'He',full([-Z(i).Ae Z(i).be]),'V',-Z(i).V,'R',-Z(i).R);
        R(i) = zonotope(-Z(i).p,Z(i).G,tmp);
    end
    
end