function [ V, Z ] = volume(Z)
% VOLUME Calculates volume of a zonotope
%
% V = volume(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% Computes volume of a given zonotope
%
%   V = volume(Z)
%
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z                      - Zonotope
%
% ---------------------------------------------------------------------------
% OUTPUT                                                                                                    
% ---------------------------------------------------------------------------
% V     - Volume of the zonotope.
% Z     - Z updated
%
% see also EXTREME
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    if ~isa(Z, 'zonotope')
        error('VOLUME: Argument MUST be a zonotope object');
    end
    
    if length(Z)~=1
        error('VOLUME: Zonotope array does not allowed')
    end
    
    Z = Z.computeHRep;
    
    V = volume@Polyhedron(Z);
end