function [ P, Z ] = zonotope2Polyhedron(Z)
% ZONOTOPE2POLYHEDRON From zonotope object to Polyhedron object
%
% [ P Z ] = zonotope2Polyhedron(Z)
%
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------
% From zonotope object to Polyhedron object 
%
% [ P Z ] = ZONOTOPE2POLYHEDRON(Z)
%   
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% Z zonotope
%  
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% P Polyhedron object
% Z zonotope updated
% 
% see also ZONOTOPE POLYHEDRON

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    if ~isa(Z,'zonotope')
        error('ZONOTOPE2POLYHEDRON: Argument MUST be a zonotope object');
    end
    
    Z = Z.computeHRep;
    
    lenZ = length(Z);
    
    P(lenZ,1) = Polyhedron;
    for i=1:lenZ        
        P(i) = Polyhedron('irredundantVRep',Z(i).irredundantVRep,'irredundantHRep',Z(i).irredundantHRep,'H',[Z(i).A Z(i).b],'He',[Z(i).Ae Z(i).be],'V',Z(i).V,'R',Z(i).R);
    end
    
end