function test = isinside(obj,x)
% ISINSIDE Checks if a given point x lies in an RCI set
%
% test = isinside(obj,x)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Checks if a given point x lies in the set given by zonotope RCI
% object obj
% 
% USAGE: 
%  
% test = obj.ISINSIDE(x)
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% x = point of the same dimension of the RCI
%  
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% test = 1 if the point is inside, 0 otherwise
%
%
%
% see also ZONOTOPE ZONOTOPERCI

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Giuseppe Giorgio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giuseppe.giorgio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------


    if size(x,1)~=size(obj.A,1) || size(x,2)~=1
        error('ISINSIDE: parameters dimensions');
    end
    
    test = isinside(obj.Zrci,x);
    
end