function [ modelTrucks1Dc, modelTrucks1Dd ] = makeModelTrucks1Dcen(N)
% MAKEMODELTRUCKS1DCEN create model trucks in 1D
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end 
    
    % constraints on state
    maxx          = 1.5;
    minx          = 1.5;
    maxvx         = 0.8;
    minvx         = 0.8;
    
    % values to choose constraints on input
    maxu          = 1.5;
    minu          = 1.0;    
    
    minM  = 5;
    maxM  = 10;
    mink  = 0.5;
    maxk  = 0.5;
    minh  = 0.5;
    maxh  = 0.5;
    M = minM+rand(1,N)*(maxM-minM);
    k = mink+rand(1,N-1)*(maxk-mink);
    h = minh+rand(1,N-1)*(maxh-minh);
    
    tic
    % local dynamics for each truck and coupling terms among trucks
    modelTrucks1Dc = lss;
    modelTrucks1Dc = modelTrucks1Dc.addSystem ([0,1;-k(1)/M(1),-h(1)/M(1)],[0;100/M(1)]);
    for i=2:N-1
        modelTrucks1Dc = modelTrucks1Dc.addSystem   ([0,1;-(k(i-1)+k(i))/M(i),-(h(i-1)+h(i))/M(i)],[0;100/M(i)]);
        modelTrucks1Dc = modelTrucks1Dc.addCoupling (i-1,i,[0,0;k(i-1)/M(i-1),h(i-1)/M(i-1)],zeros(2,1));
        modelTrucks1Dc = modelTrucks1Dc.addCoupling (i,i-1,[0,0;k(i-1)/M(i),h(i-1)/M(i)],zeros(2,1));
    end
    modelTrucks1Dc = modelTrucks1Dc.addSystem   ([0,1;-k(N-1)/M(N),-h(N-1)/M(N)],[0;100/M(N)]);
    modelTrucks1Dc = modelTrucks1Dc.addCoupling (N,N-1,[0,0;k(N-1)/M(N),h(N-1)/M(N)],zeros(2,1));
    modelTrucks1Dc = modelTrucks1Dc.addCoupling (N-1,N,[0,0;k(N-1)/M(N-1),h(N-1)/M(N-1)],zeros(2,1));
    
    for i=1:N
        modelTrucks1Dc = modelTrucks1Dc.addCentralizedInput([0;100/M(i)],[],i,1);
    end
    modelTrucks1Dc = modelTrucks1Dc.addCentralizedInputConstraint(1,[1;-1],[0.5;0.5]);
 
    clear M k h 
    
    % state constraints
    for i=1:modelTrucks1Dc.numSys
        modelTrucks1Dc = modelTrucks1Dc.addStateConstraint(i,[eye(2);-eye(2)],[maxx,maxvx,minx,minvx]');
    end
    
    % input constraints
    u = linspace(minu,maxu,10);
    for i=1:modelTrucks1Dc.numSys
        ind = fix(length(u)*rand(1)+1);
        modelTrucks1Dc = modelTrucks1Dc.addInputConstraint(i,[eye(1);-eye(1)],[u(ind),u(ind)]');
    end
    
    time_modelC = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/cenmpc/1D/modelTrucks1Dccen'],'modelTrucks1Dc','time_modelC')
    
    tic
    modelTrucks1Dd = modelTrucks1Dc.clss2dlss(0.2,'subsystem');
    time_modelDss = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/cenmpc/1D/modelTrucks1Ddcen'],'modelTrucks1Dd','time_modelDss')
    
end