function [ x, u ] = runSimTrucks1D_disturbances_bounded_cen(Tsim,x0,modelTrucks1Dc,modelTrucks1Dd,Trucks1Dcenmpc,options)
% RUNSIMTRUCKS1D_DISTURBANCES_BOUNDED run a simulation for the trucks model in 1D using cenmpc controllers with initial state x0 and Tsim istant times
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end    

    if nargin<=5
        options = sdpsettings('verbose',0);
    end

    if verLessThan('matlab', '7.12')
        rand('seed');
    else
        rng('default');
    end
    
    xsim   = [];
    timeX  = [];
    usim   = [];
    dsim   = [];
    
    for t=0:Tsim-1        
        
        fprintf('Running... Time: %d\n',t)
        
        uRH   = Trucks1Dcenmpc.uRH(x0,[],[],[],options);
        
        d = -modelTrucks1Dd.Kd(2:2:end)+rand(sum(modelTrucks1Dd.ni),1).*(modelTrucks1Dd.Kd(1:2:end)+modelTrucks1Dd.Kd(2:2:end));
        
        x0ode = ode45(@(tt,x)simulatorTrucksCen(tt,x,uRH,d,modelTrucks1Dc),[0 modelTrucks1Dd.Ts],x0);
        x0    = x0ode.y(:,end);
        
        xsim   = [ xsim  ; x0ode.y(:,1:end-1)' ];
        timeX  = [ timeX ; t*modelTrucks1Dd.Ts + x0ode.x(1:end-1)' ];
        usim   = [ usim  ; uRH' ];
        dsim   = [ dsim  ; d' ];
    end
    
    xsim                   = [ xsim  ; x0ode.y(:,end)' ];
    timeX                  = [ timeX ; t*modelTrucks1Dd.Ts + x0ode.x(end) ];
    
    u.signals.values       = usim(:,1:end-1);
    u.signals.dimensions   = size(usim(:,1:end-1),2);
    u.time                 = 0:modelTrucks1Dd.Ts:modelTrucks1Dd.Ts*(Tsim-1);
    
    uc.signals.values      = usim(:,end);
    uc.signals.dimensions  = 1;
    uc.time                = 0:modelTrucks1Dd.Ts:modelTrucks1Dd.Ts*(Tsim-1);
    
    x.signals.values       = xsim;
    x.signals.dimensions   = size(xsim,2);
    x.time                 = timeX;
    
    
    modelTrucks1Dc.plotX([],[],x);
    axis tight
    modelTrucks1Dc.stairsU([],[],u);
    axis tight
    modelTrucks1Dc.stairsUcen(uc);
    axis tight
    figure;
    title('Disturbances');
    hold on
    box on
    for nd = 1:sum(modelTrucks1Dd.ni)
        stairs(0:modelTrucks1Dd.Ts:modelTrucks1Dd.Ts*(Tsim-1),dsim(:,nd));
    end
    axis tight
    
end