function [ modelSystem ] = makeModelSystem_lse
% MAKEMODELSYSTEM_LSE create a large-scale system with bounded disturbances
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end 
    
    modelSystem = lss;
    modelSystem = modelSystem.addSystem([0.1 0.3 0;0.1 0 0.3;-0.3 0.3 0.3],eye(3),[1 0 0;0 -1 0],[],[],-1);
    modelSystem = modelSystem.addSystem([0 0.5 0;0 0 0.5;-0.1 0.2 0.3],eye(3),[1 0 0;0 -1 0],[],[],-1);
    modelSystem = modelSystem.addSystem([0.1 0.1 0;0 0 0.1;0.3 -0.1 0.2],eye(3),[1 0 0;0 -1 0],[],[],-1);
    
    modelSystem = modelSystem.addCoupling(1,2,[-0.1 0 0;0 0 0;0 0 0.1]);
    modelSystem = modelSystem.addCoupling(1,3,[0.1 0.1 0;0 0 0.1;0 0 0]);
    
    modelSystem = modelSystem.addCoupling(2,1,[0 0 0;0 0.1 0;0 0 0.1]);
    modelSystem = modelSystem.addCoupling(2,3,[-0.1 0.1 0;0 0 0;0 0 0.1]);
    
    modelSystem = modelSystem.addCoupling(3,1,[0.1 0 0;0.1 0.1 0;0 0 0.1]);
    modelSystem = modelSystem.addCoupling(3,2,[0 0 0;0 0 0;0 0 0.1]);
    
    for i=1:modelSystem.numSys
        modelSystem = modelSystem.addErrorEstimationConstraint(i,[eye(modelSystem.ni(i));-eye(modelSystem.ni(i))],ones(2*modelSystem.ni(i),1));
    end
    
    n = sum(modelSystem.ni);    
    modelSystem = modelSystem.addExoInput(eye(n));    
    
    for i=1:modelSystem.numExo
        modelSystem = modelSystem.addExoConstraint(i,[1;-1],[0.075;0.075]);
    end
    
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/lse/modelSystem'],'modelSystem')
    
end