function [ x, xest, eest ] = simulationLSE( modelSystem , estLSE )
% SIMULATIONLSE run a simulation to estimate states of modelSystem using large-scale estimator estLSE
%

% Copyright is with the following author(s):
%
% (C) 2014 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    N    = 15;
    
    n    = size(modelSystem.getA,2);
    m    = size(modelSystem.getB,2);
    p    = size(modelSystem.getC,1);
    ni   = n/modelSystem.numSys;
    
    u    = repmat(-1+rand(m,1)*2,1,N)+repmat(sin((0:N-1)),m,1);
    x    = zeros(n,N+1) ;
    xest = zeros(n,N+1) ;
    y    = zeros(p,N);
    
    w    = repmat(-modelSystem.Kd(n+1:end),1,N)+rand(n,N).*repmat(modelSystem.Kd(1:n)+modelSystem.Kd(n+1:end),1,N);
    
    for i=1:modelSystem.numSys
        v = estLSE.ThetaDec{2}(i,1)*estLSE.Si(i).LP.V;
        xest((i-1)*ni+1:i*ni,1) = v(randi(size(v,1)),:)';
    end
    
    
    for t=1:N
        x(:,t+1) = modelSystem.getA*x(:,t) + modelSystem.getB*u(:,t) + modelSystem.getM*w(:,t);
        y(:,t)   = modelSystem.getC*x(:,t) ;
        
        xest(:,t+1) = estLSE.globalEstimator(x(:,t),y(:,t),u(:,t));
    end
    
    eest  = x-xest;
    
    fig1 = figure(1);
    axes1 = axes('Parent',fig1,'FontSize',22);
    Tx  = N;
    hold on
    box on
    plot(0:(Tx-1),x(1:3,1:Tx)','--','LineWidth',1)
    plot(0:(Tx-1),xest(1:3,1:Tx)','LineWidth',1)
    xlabel('t','FontSize',22);
    ylabel('x_{[1,1:3]}','FontSize',22);
    
    fig2 = figure(2);
    axes2 = axes('Parent',fig2,'FontSize',22);
    ylim([-1.2 1.2]);
    hold on
    box on
    plot(0:N,eest','b','LineWidth',1)
    xlabel('t','FontSize',22);
    ylabel('e','FontSize',22);
    
    
    mkdir([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/lse/simulations'])
    saveas(fig1,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/lse/simulations/xest_sub1'],'fig')
    saveas(fig2,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/lse/simulations/error_est'],'fig')
    saveas(fig1,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/lse/simulations/xest_sub1'],'epsc')
    saveas(fig2,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/lse/simulations/error_est'],'epsc')
    
end