function [] = makeAllPNSfiles( controller )
% MAKEALLPNSFILES create all files for the power network system proposed as benchmark and run all simulations. Attention: different performance can be achieved using different solvers
%
% Input parameter 'controller'
% 1 - Polytope State Constraints, Input Constraints, Decentralized design
% 2 - Polytope State Constraints, Decentralized design
% 3 - Polytope State Constraints, Distributed design
% 4 - Zonotope State Constraints, Input Constraints, Decentralized design
% 5 - Zonotope State Constraints, Decentralized design
% 6 - Zonotope State Constraints, Distributed design
%

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
% (C) 2012
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
%
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the
%          Free Software Foundation, Inc.,
%          59 Temple Place, Suite 330,
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    if nargin==0 || controller<1 || controller>6
        disp('1 - Polytope State Constraints, Input Constraints, Decentralized design')
        disp('2 - Polytope State Constraints, Decentralized design')
        disp('3 - Polytope State Constraints, Distributed design')
        disp('4 - Zonotope State Constraints, Input Constraints, Decentralized design')
        disp('5 - Zonotope State Constraints, Decentralized design')
        disp('6 - Zonotope State Constraints, Distributed design')
        error('MAKEPNPMPCCONTROLLERSPNS: input parameter controller must be between 1 and 6')
    end

    makePnpmpcControllersPNS( controller )
    
    options = sdpsettings('verbose',0,'cachesolvers',1); 
    
    scenario1Full(options)
    scenario1Zero(options)
    scenario2Full(options)
    scenario2Zero(options)
    scenario3Full(options)
    scenario3Zero(options)
    
end