function [] = makeScenariosPNS()
% MAKESCENARIOSPNS create power network systems as lss objects
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    close all

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    H = [12 10 8 8 10];
    R = [0.05 0.0625 0.08 0.08 0.05];
    D = [0.7 0.9 0.9 0.7 0.86];
    Tt = [0.65 0.4 0.3 0.6 0.8];
    Tg =[0.1 0.1 0.1 0.1 0.15];
    P = zeros(5);
    P(1,2) = 4;
    P(2,3) = 2;
    P(3,4) = 2;
    P(4,5) = 3;
    P(2,5) = 3;
    P = P+P';
    
    DtetaMIN = [0.1 0.1 0.1 0.1 0.1];
    DtetaMAX =[0.1 0.1 0.1 0.1 0.1];
    DrefMIN = [0.5 0.65 0.65 0.55 0.5];
    DrefMAX = [0.5 0.65 0.65 0.55 0.5];
    
    link{1} =2;
    link{2} = [1,3];
    link{3} =[2,4];
    link{4} = 3;
    
    
    %% Scenario 1
    N = 4;
    pnsC1 = lss();
    
    % add each area
    for i =1:N
        A = [0                           1                  0             0    ;
            -sum(P(1:N,i))/(2*H(i))   -D(i)/(2*H(i))      1/(2*H(i))      0    ;
            0                            0                -1/Tt(i)      1/Tt(i);
            0                         -1/(R(i)*Tg(i))       0          -1/Tg(i)];
        B = [0 0 0 1/Tg(i)]';
        L = [0 -1/(2*H(i)) 0 0]';
        
        % add an area
        pnsC1 = pnsC1.addSystem(A,B,[],[],['Area ', int2str(i)]);
        
        % add exogenous input (DeltaPLi)
        pnsC1 = pnsC1.addExoInput(L,zeros(4,1),i,i);
        
        % state constraints
        pnsC1 = pnsC1.addStateConstraint (i,[1 0 0 0;-1 0 0 0],[DtetaMAX(i) DtetaMIN(i)]');
        
        % input constraints
        pnsC1 = pnsC1.addInputConstraint (i, [1 -1]',[DrefMAX(i) DrefMIN(i)]');
        
        % name of variables
        pnsC1 = pnsC1.setNamex (i, {strcat('\Delta\delta_',num2str(i)); strcat('\Delta\omega_',num2str(i));strcat('\Delta P_{m_',num2str(i),'}');strcat('\Delta P_{v_',num2str(i),'}')});
        pnsC1 = pnsC1.setNameu (i, {strcat('\Delta P_{ref_',num2str(i),'}')});
        pnsC1 = pnsC1.setNamed (i, strcat('\Delta P_{L_',num2str(i),'}'));
        
    end
    
    % coupling matrices
    for i = 1:N
        for j = link{i}
            Aij = zeros(4);
            Aij(2,1) = P(i,j)/(2*H(i));
            pnsC1 = pnsC1.addCoupling (i,j,Aij);
        end
    end
    
    % Discretization with Ts = 1 sec using zoh and system-by-system
    pnsD1   = pnsC1.clss2dlss(1);
    pnsD1ss = pnsC1.clss2dlss(1,'subsystem');
    
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario1/pnsC1'],'pnsC1')
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario1/pnsD1'],'pnsD1')
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario1/pnsD1ss'],'pnsD1ss')
    
    
    
    
    %% Scenario 2
    % Differently from Scenario 1, area 5 is added
    
    % link for area 5
    link{2} = [link{2},5];
    link{4} = [link{4},5];
    link{5} = [2,4];
    
    pnsC2 = pnsC1;
    A = [0                           1                  0           0     ;
        -sum(P(:,5))/(2*H(5))    -D(5)/(2*H(5))      1/(2*H(5))    0     ;
        0                           0               -1/Tt(5)      1/Tt(5);
        0                         -1/(R(5)*Tg(5))      0         -1/Tg(5)];
    B = [0 0 0 1/Tg(5)]';
    L = [0 -1/(2*H(5)) 0 0]';
    
    % add area 5
    pnsC2 = pnsC2.addSystem(A,B,[],[],strcat('Area 5'));
    
    % coupling matrices among areas 5 and 2, areas 5 and 4
    for j = link{5}
        Aij = zeros(4);
        Aij(2,1) = P(5,j)/(2*H(5));
        pnsC2 = pnsC2.addCoupling (5,j,Aij);
        Aij(2,1) = P(j,5)/(2*H(j));
        pnsC2 = pnsC2.addCoupling (j,5,Aij);
    end
    
    % Attention: if we add a new area the local dynamics of successors changes
    A = pnsC2.getA('Area 2');
    A(2,1) = A(2,1) - P(2,5)/(2*H(2));
    pnsC2 = pnsC2.setA(A,2);
    
    A = pnsC2.getA(4);
    A(2,1) = A(2,1) - P(4,5)/(2*H(4));
    pnsC2 = pnsC2.setA(A,4);
    
    % add exogenous input (DeltaPL5)
    pnsC2 = pnsC2.addExoInput(L,zeros(4,1),5,5);
    
    % name of variables for area 5
    pnsC2 = pnsC2.setNamex (5, {'\Delta\delta_5'; '\Delta\omega_5';'\Delta P_{m_5}' ;'\Delta P_{v_5}'});
    pnsC2 = pnsC2.setNameu (5, {'\Delta P_{ref_5}'});
    pnsC2 = pnsC2.setNamed (5, '\Delta P_{L_5}');
    
    % state constraints of area 5
    pnsC2 = pnsC2.addStateConstraint (5,[1 0 0 0;-1 0 0 0],[DtetaMAX(5) DtetaMIN(5)]');
    
    % input constraints of area 5
    pnsC2 = pnsC2.addInputConstraint (5, [1 -1]',[DrefMAX(5) DrefMIN(5)]');
    
    % Discretization with Ts = 1 sec using zoh and system-by-system
    pnsD2   = pnsC2.clss2dlss(1);
    pnsD2ss = pnsC2.clss2dlss(1,'subsystem');
    
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario2/pnsC2'],'pnsC2')
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario2/pnsD2'],'pnsD2')
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario2/pnsD2ss'],'pnsD2ss')
    
    
    
    
    
    %% Scenario 3
    % We remove area 4 and update areas 2 and 5
    
    pnsC3 = pnsC2;
    
    % update local dynamics of areas 3 and 5
    A = pnsC3.getA(3);
    A(2,1) = A(2,1)+ P(3,4)/(2*H(3));
    pnsC3 = pnsC3.setA(A,3);
    
    A = pnsC3.getA(5);
    A(2,1) = A(2,1)+ P(5,4)/(2*H(5));
    pnsC3 = pnsC3.setA(A,5);
    
    % remove area 4
    pnsC3 = pnsC3.removeSystem(4);
    
    % Discretization with Ts = 1 sec using zoh and system-by-system
    pnsD3   = pnsC3.clss2dlss(1);
    pnsD3ss = pnsC3.clss2dlss(1,'subsystem');
    
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario3/pnsC3'],'pnsC3')
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario3/pnsD3'],'pnsD3')
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario3/pnsD3ss'],'pnsD3ss')
    
    simulationParameters
    
end