function [ eta Phi ] = scenario1performance(x,deltaPref,xref,uref,Q,R,Tsim)
% SCENARIO1PERFORMANCE compute performance eta and Phi of Scenario 1
%
% [ eta Phi ] = scenario1performance(x,deltaPref,xref,uref,Q,R,Tsim)
% 
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
%
% [ eta Phi ] = scenario1performance(x,deltaPref,xref,uref,Q,R,Tsim)
% 
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% x: state trajectories as struct
% deltaPref: input trajectories as struct
% xref: reference state trajectories as struct
% uref: reference input trajectories as struct
% Q and R: matrices of the overall cost function
% Tsim: time of simulation
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% eta and Phi: performance parameters of Scenario 1
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------
    if nargin~=7
        error('SCENARIO1PERFORMANCE: number input parameters')
    end

    eta = 0;
    Phi = 0;
    
    for t=0:Tsim-1
        xx = x.signals.values(t+1,:)';
        uu = deltaPref.signals.values(t+1,:)';
        xb = xref.signals.values(t+1,:)';
        ub = uref.signals.values(t+1,:)';
        
        eta = eta + (xx-xb)'*Q*(xx-xb) + (uu-ub)'*R*(uu-ub);
        Phi = Phi + 4*abs(xx(1)-xx(5)) + 2*abs(xx(5)-xx(9)) + 2*abs(xx(9)-xx(13));
    end
    
    eta = eta / Tsim;
    Phi = Phi / Tsim;
end