% PNSCTRL3 create pnpmpc controllers for power network systems of scenarios 1,2,3 with two different terminal regions
% Design: Polytope State Constraints, Distributed design
%

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

options = sdpsettings('verbose',0,'solver','sedumi');

%% Scenario 1: pnpmpc controllers
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario1/pnsD1ss'])
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario1/simulationParameters'])
pnsD1ss = pnsD1ss.removeConstraint([],'in');
% All areas
flag(1).k = {8,20}; flag(1).distributedParents = 2 ;
flag(2).k = {8,20}; flag(2).distributedParents = [ 1 3 ] ;
flag(3).k = {8,20}; flag(3).distributedParents = [ 2 4 ] ;
flag(4).k = {6,20}; flag(4).distributedParents = 3 ;
ctrlPnpMpc = pnsD1ss.createCtrlPnPMPC(N,flag,options);

ctrlPnpMpcFull = ctrlPnpMpc;
for i=1:size(ctrlPnpMpc,2)
    ctrlPnpMpcFull(i) = ctrlPnpMpc(i).XFqpmax(Q,R,sdpsettings('verbose',0));
end

ctrlPnpMpcZero = ctrlPnpMpc;
for i=1:size(ctrlPnpMpc,2)
    ctrlPnpMpcZero(i) = ctrlPnpMpc(i).zeroTerminal(Q,R);
end


save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario1/Dss_PNPMPC/full/ctrlPnpMpcFull'],'ctrlPnpMpcFull')
save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario1/Dss_PNPMPC/zero/ctrlPnpMpcZero'],'ctrlPnpMpcZero')





%% Scenario 2: pnpmpc controllers
disp('## Scenario 2 ##')
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario2/pnsD2ss'])
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario2/simulationParameters'])
pnsD2ss = pnsD2ss.removeConstraint([],'in');
% Area 2
flag(2).k = { 8 , 20 }; flag(2).distributedParents = [ 1 3 5 ] ;
sub2 = pnsD2ss.getSystem(2);
[H1 K1] = pnsD2ss.doubleStateConstraint(1);
[H3 K3] = pnsD2ss.doubleStateConstraint(3);
[H5 K5] = pnsD2ss.doubleStateConstraint(5);
ctrlPnpMpc(2) = pnpmpc(sub2,N,{H1,K1;H3,K3;H5,K5},[],flag(2),options);

% Area 4
flag(4).k = { 8 , 20 }; flag(4).distributedParents = [ 3 5 ] ;
sub4 = pnsD2ss.getSystem(4);
[H3 K3] = pnsD2ss.doubleStateConstraint(3);
[H5 K5] = pnsD2ss.doubleStateConstraint(5);
ctrlPnpMpc(4) = pnpmpc(sub4,N,{H3,K3;H5,K5},[],flag(4),options);

% Area 5
flag(5).k = { 5 , 20 }; flag(5).distributedParents = [ 2 4 ] ;
sub5 = pnsD2ss.getSystem(5);
[H2 K2] = pnsD2ss.doubleStateConstraint(2);
[H4 K4] = pnsD2ss.doubleStateConstraint(4);
ctrlPnpMpc(5) = pnpmpc(sub5,N,{H2,K2;H4,K4},[],flag(5),options);


for i=[2 4 5]
    ctrlPnpMpcFull(i) = ctrlPnpMpc(i).XFqpmax(Q,R,sdpsettings('verbose',0));
end
for i=[2 4 5]
    ctrlPnpMpcZero(i) = ctrlPnpMpc(i).zeroTerminal(Q,R);
end

save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario2/Dss_PNPMPC/full/ctrlPnpMpcFull'],'ctrlPnpMpcFull')
save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario2/Dss_PNPMPC/zero/ctrlPnpMpcZero'],'ctrlPnpMpcZero')




%% Scenario 3: pnpmpc controllers
disp('## Scenario 3 ##')
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario3/pnsD3ss'])
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario3/simulationParameters'])
pnsD3ss = pnsD3ss.removeConstraint([],'in');
% Remove Area 4
ctrlPnpMpc(4) = [];
ctrlPnpMpcFull(4) = [];
ctrlPnpMpcZero(4) = [];

% Area 3
flag(3).k = { 8 , 20 }; flag(3).distributedParents = 2 ;
sub3 = pnsD3ss.getSystem(3);
[H2 K2] = pnsD3ss.doubleStateConstraint(2);
ctrlPnpMpc(3) = pnpmpc(sub3,N,{H2,K2},[],flag(3),options);

% Area 5
flag(5).k = { 8 , 20 }; flag(5).distributedParents = 2 ;
sub5 = pnsD3ss.getSystem('Area 5');
[H2 K2] = pnsD3ss.doubleStateConstraint(2);
ctrlPnpMpc(4) = pnpmpc(sub5,N,{H2,K2},[],flag(5),options);


for i=[3 4]
    ctrlPnpMpcFull(i) = ctrlPnpMpc(i).XFqpmax(Q,R,sdpsettings('verbose',0));
end
for i=[3 4]
    ctrlPnpMpcZero(i) = ctrlPnpMpc(i).zeroTerminal(Q,R);
end

save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario3/Dss_PNPMPC/full/ctrlPnpMpcFull'],'ctrlPnpMpcFull')
save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario3/Dss_PNPMPC/zero/ctrlPnpMpcZero'],'ctrlPnpMpcZero')