function [ x u ] = sim1PNS(objCtrl,objsysD,objsysC,Tsim,x0,exosignals,xref,uref,options)
% SIM1PNS simulate power network system using decentralized pnpmpc controllers
%

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------


    xsim = x0';
    usim = [];
    
    ni = objsysD.ni;
    mi = objsysD.mi;
    
    for t=0:Tsim-1
        
        fprintf('Running... Time: %d\n',t)
        
        uRH = zeros(objsysD.numSys,1);
        parfor i=1:objsysD.numSys
            uRH(i) = objCtrl(i).uRH(x0(sum(ni(1:i-1))+1:sum(ni(1:i)),1),[],[],exosignals.signals.values(t+1,objCtrl(i).Exo),xref.signals.values(t+1,sum(ni(1:i-1))+1:sum(ni(1:i)),1)',uref.signals.values(t+1,sum(mi(1:i-1))+1:sum(mi(1:i)),1)',options);
        end
        x0ode = ode45(@(tt,x)simulatorPNS(tt,x,uRH,exosignals.signals.values(t+1,:)',objsysC),[0 objsysD.Ts],x0);
        x0 = x0ode.y(:,end);
        
        
        xsim = [ xsim ; x0'  ];
        usim = [ usim ; uRH' ];
        
    end
    
    clear x u
    
    u.signals.values = usim;
    u.signals.dimensions = size(usim,2);
    u.time = 0:Tsim-1;
    
    x.signals.values = xsim;
    x.signals.dimensions = size(xsim,2);
    x.time = 0:Tsim;
    
end