% SIMULATIONPARAMETERS create simulation parameters for scenarios 1,2,3
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

%% Scenario 1: simulation parameters
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario1/pnsC1'])
Tsim  = 100;

deltaPL.signals.values = zeros(Tsim,size(pnsC1.M,2));
deltaPL.signals.dimensions = size(pnsC1.M,2);
deltaPL.time = 0:Tsim-1;
deltaPL.signals.values(5+1:end,1) = .15;
deltaPL.signals.values(15+1:end,2) = -.15;
deltaPL.signals.values(20+1:40,3) = .12;
deltaPL.signals.values(40+1:end,3) = -.12;
deltaPL.signals.values(40+1:end,4) = .28;

xref.signals.values = zeros(Tsim+1,size(pnsC1.A,1));
xref.signals.values(:,3:4:end) = [ deltaPL.signals.values ; deltaPL.signals.values(end,:) ];
xref.signals.values(:,4:4:end) = [ deltaPL.signals.values ; deltaPL.signals.values(end,:) ];
xref.signals.dimensions = size(pnsC1.A,1);
xref.time = 0:Tsim;

uref.signals.values = deltaPL.signals.values;
uref.signals.dimensions = size(pnsC1.B,1);
uref.time = 0:Tsim-1;

x0      = zeros(size(pnsC1.A,1),1);

A       = full(pnsC1.getA);
B       = [ full(pnsC1.getB) full(pnsC1.getM) ];
C       = full(pnsC1.getC);
D       = [ full(pnsC1.getD) full(pnsC1.getN) ];

Q = diag([500 0.01 0.01 10]);
R = 10;
N = 15;


save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario1/simulationParameters'],'Tsim','x0','deltaPL','xref','uref','A','B','C','D','Q','R','N')


%% Scenario 2: simulation parameters
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario2/pnsC2'])

deltaPL.signals.values = zeros(Tsim,size(pnsC2.M,2));
deltaPL.signals.dimensions = size(pnsC2.M,2);
deltaPL.time = 0:Tsim-1;
deltaPL.signals.values(5+1:20,1) = .1;
deltaPL.signals.values(20+1:end,1) = -.22;
deltaPL.signals.values(15+1:20,2) = -.16;
deltaPL.signals.values(20+1:end,2) = .12;
deltaPL.signals.values(20+1:30,3) = -.1;
deltaPL.signals.values(30+1:end,3) = .1;
deltaPL.signals.values(40+1:end,4) = .08;
deltaPL.signals.values(40+1:end,5) = -.1;

xref.signals.values = zeros(Tsim+1,size(pnsC2.A,1));
xref.signals.values(:,3:4:end) = [ deltaPL.signals.values ; deltaPL.signals.values(end,:) ];
xref.signals.values(:,4:4:end) = [ deltaPL.signals.values ; deltaPL.signals.values(end,:) ];
xref.signals.dimensions = size(pnsC2.A,1);
xref.time = 0:Tsim;

uref.signals.values = deltaPL.signals.values;
uref.signals.dimensions = size(pnsC2.B,1);
uref.time = 0:Tsim-1;
             
x0      = zeros(size(pnsC2.A,1),1);

A       = full(pnsC2.getA);
B       = [ full(pnsC2.getB) full(pnsC2.getM) ];
C       = full(pnsC2.getC);
D       = [ full(pnsC2.getD) full(pnsC2.getN) ];

save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario2/simulationParameters'],'Tsim','x0','deltaPL','xref','uref','A','B','C','D','Q','R','N')

%% Scenario 3: simulation parameters
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/modelPNS/scenario3/pnsC3'])
%                time steop indexArea (Area1=1,Area2=2,Area3=3,Area5=4)
loadStep    = [    5   .12   1 ;
                  15  -.15   2 ;
                  20   .2    4 ;
                  40  -.2    4 ;
                  40   .13   3 ;
                  40   .15   2 ];

deltaPL.signals.values = zeros(Tsim,size(pnsC3.M,2));
deltaPL.signals.dimensions = size(pnsC3.M,2);
deltaPL.time = 0:Tsim-1;
deltaPL.signals.values(5+1:end,1) = .12;
deltaPL.signals.values(15+1:40,2) = -.15;
deltaPL.signals.values(40+1:end,2) = .15;
deltaPL.signals.values(40+1:end,3) = .13;
deltaPL.signals.values(20+1:40,4) = .2;
deltaPL.signals.values(40+1:end,4) = -.2;
              
xref.signals.values = zeros(Tsim+1,size(pnsC3.A,1));
xref.signals.values(:,3:4:end) = [ deltaPL.signals.values ; deltaPL.signals.values(end,:) ];
xref.signals.values(:,4:4:end) = [ deltaPL.signals.values ; deltaPL.signals.values(end,:) ];
xref.signals.dimensions = size(pnsC3.A,1);
xref.time = 0:Tsim;

uref.signals.values = deltaPL.signals.values;
uref.signals.dimensions = size(pnsC3.B,1);
uref.time = 0:Tsim-1;

x0      = zeros(size(pnsC3.A,1),1);

A       = full(pnsC3.getA);
B       = [ full(pnsC3.getB) full(pnsC3.getM) ];
C       = full(pnsC3.getC);
D       = [ full(pnsC3.getD) full(pnsC3.getN) ];

save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/modelPNS/scenario3/simulationParameters'],'Tsim','x0','deltaPL','xref','uref','A','B','C','D','Q','R','N')