function [ modelTrucks2Dc, modelTrucks2Dd, modelTrucks2Dddist ] = makeModelTrucks2Dgroup4(N)
% MAKEMODELTRUCKS2DGROUP4 create model trucks in 2D, N number of subsystems (for each subsystem there are 4 masses)
%

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    ele           = sqrt(N);
    
    minM          = 5   ;
    maxM          = 10  ;
    k             = 0.5 ;
    h             = 0.5 ;
    
    
    % constraints on state
    maxx          = 1;
    minx          = -1;
    maxy          = 1;
    miny          = -1;
    maxvx         = 1.5;
    minvx         = -1.5;
    maxvy         = 1.5;
    minvy         = -1.5;
    
    MM            = floor((minM+rand(1,N*4)*(maxM-minM))*1000)/1000;
    
    
    Aii           = @(M)( [ 0 1 0 0 ; -(k+k)/M -(h+h)/M 0 0 ; 0 0 0 1 ; 0 0 -(k+k)/M -(h+h)/M ] );
    Aih           = @(M)( [ 0 0 0 0 ; k/M h/M 0 0 ; 0 0 0 0 ; 0 0 0 0 ] );
    Aiv           = @(M)( [ 0 0 0 0 ; 0 0 0 0 ; 0 0 k/M h/M ; 0 0 0 0 ] );
    Bii           = @(M)( [ 0 0 ; 100/M 0 ; 0 0 ; 0 100/M ] );
    
    Aijr          = @(M)( [ zeros(4,16) ; Aih(M(2)) zeros(4,12) ; zeros(4,16) ; zeros(4) Aih(M(4)) zeros(4,8) ] );
    Aijl          = @(M)( [ zeros(4) Aih(M(1)) zeros(4,8) ; zeros(4,16) ; zeros(4,12) Aih(M(3)) ; zeros(4,16) ] );
    Aiju          = @(M)( [ zeros(4,8) Aiv(M(1)) zeros(4) ; zeros(4,12) Aiv(M(2)) ; zeros(8,16) ] );
    Aijd          = @(M)( [ zeros(8,16) ; Aiv(M(3)) zeros(4,12) ; zeros(4) Aiv(M(4)) zeros(4,8) ] );
    
    A             = @(M)( [ Aii(M(1)) Aih(M(1)) Aiv(M(1)) zeros(4) ; Aih(M(2)) Aii(M(2)) zeros(4) Aiv(M(2)) ; Aiv(M(3)) zeros(4) Aii(M(3)) Aih(M(3)) ; zeros(4) Aiv(M(4)) Aih(M(4)) Aii(M(4)) ] );
    B             = @(M)( blkdiag(Bii(M(1)),Bii(M(2)),Bii(M(3)),Bii(M(4))) );
    
    C             = blkdiag([ 1 0 0 0 ; 0 0 1 0 ],[ 0 1 0 0 ; 0 0 0 1 ],[ 0 1 0 0 ; 0 0 0 1 ],[ 1 0 0 0 ; 0 0 1 0 ]);
    
    
    tic
    modelTrucks2Dc     = lss;
    
    % local dynamics for each truck
    for n = 1:N
        Mi = MM((n-1)*4+1:n*4);
        modelTrucks2Dc = modelTrucks2Dc.addSystem ( A(Mi) , B(Mi) , C , zeros(size(C,1),8) );
    end
    
    
    % coupling terms among group of trucks
    for i=1:ele
        for j=1:ele
            cont = (i-1)*ele + j;
            Mi = MM((cont-1)*4+1:cont*4);
            
            if j<=ele-1
                modelTrucks2Dc = modelTrucks2Dc.addCoupling(cont,cont+1,Aijr(Mi));
            end
            
            if j>=2
                modelTrucks2Dc = modelTrucks2Dc.addCoupling(cont,cont-1,Aijl(Mi));
            end
            
            if i>=2
                modelTrucks2Dc = modelTrucks2Dc.addCoupling(cont,cont-ele,Aiju(Mi));
            end
            
            if i<=ele-1
                modelTrucks2Dc = modelTrucks2Dc.addCoupling(cont,cont+ele,Aijd(Mi));
            end
            
            modelTrucks2Dc = modelTrucks2Dc.addErrorEstimationConstraint(cont,[eye(4*4);-eye(4*4)],[repmat([maxx,maxvx,maxy,maxvy]',4,1) ; repmat(-[minx,minvx,miny,minvy]',4,1)]);
            
        end
    end
    
    
    time_modelC = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/modelTrucks2Dc'],'modelTrucks2Dc','time_modelC')
    
    tic
    modelTrucks2Dd = modelTrucks2Dc.clss2dlss(0.2,'subsystem');
    time_modelDss = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/modelTrucks2Dd'],'modelTrucks2Dd','time_modelDss')
    
    Mr = ones(16,1);
    M  = [];
    for i=1:modelTrucks2Dc.numSys
        M = blkdiag(M,Mr);
    end
    modelTrucks2Dddist = modelTrucks2Dd.addExoInput(M);
    modelTrucks2Dddist = modelTrucks2Dddist.addExoConstraint(1:modelTrucks2Dd.numSys,[eye(modelTrucks2Dd.numSys);-eye(modelTrucks2Dd.numSys)],1.5e-2*ones(modelTrucks2Dd.numSys*2,1));
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/modelTrucks2Dddist'],'modelTrucks2Dddist')
end