function [ PnPestimators, PnPestimatorsOutputs, PnPestimatorsdist, PnPestimatorsOutputsdist ] = makePnpEstimatorTrucks2Dgroup4(modelTrucks2Dd,modelTrucks2Dddist)
% MAKEPNPMPCTRUCKS2DGROUP4 create pnp state estimators for model trucks in 2D (for each subsystem there are 4 masses) with and without disturbances
%
% Be careful, the computation of all pnp state estimators for this large-scale
% system could take some minutes

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    disp(' ');
    disp(' ');
    disp('Be careful, the computation of all pnp state estimators (4 different types) for this VERY large-scale system could take minutes');
    disp(' ');
    disp(' ');
    
    for i=1:modelTrucks2Dd.numSys
        flag(i).boundedEstimation = 1;
        flag(i).Qi = 0.01*eye(modelTrucks2Dd.ni(i));
        flag(i).Ri = 100*eye(modelTrucks2Dd.pi(i));
        flag(i).norm = 'F';
        
        flagdist(i) = flag(i);
        flagOut(i) = flag(i);
        flagOutDist(i) = flag(i);
    end
    
    for i=1:modelTrucks2Dd.numSys
        flagdist(i).ExoBounded = i;
        flagOutDist(i).ExoBounded = i;
    end
    
    for i=1:modelTrucks2Dd.numSys
        flagOut(i).distributedParents = setdiff(full(find(modelTrucks2Dd.couplingmatrix(i,:))),i);
        flagOutDist(i).distributedParents = setdiff(full(find(modelTrucks2Dd.couplingmatrix(i,:))),i);
    end
    
    
    tic
    [ PnPestimatorsdist , L1 ] = modelTrucks2Dddist.createPnPEstimators(flagdist);
    time_pnp = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/PnPestimatorsdist'],'PnPestimatorsdist','time_pnp','L1')
    
    
    tic
    [ PnPestimatorsOutputsdist , L2 ] = modelTrucks2Dddist.createPnPEstimators(flagOutDist);
    time_pnp = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/PnPestimatorsOutputsdist'],'PnPestimatorsOutputsdist','time_pnp','L2')
    
    
    tic
    [ PnPestimators , L3 ] = modelTrucks2Dd.createPnPEstimators(flag);
    time_pnp = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/PnPestimators'],'PnPestimators','time_pnp','L3')
    
    
    tic
    [ PnPestimatorsOutputs , L4 ] = modelTrucks2Dd.createPnPEstimators(flagOut);
    time_pnp = toc;
    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/PnPestimatorsOutputs'],'PnPestimatorsOutputs','time_pnp','L4')
    
end