function [] = simulationEstimatordist( )
% SIMULATIONESTIMATORDIST simulate pnp state estimators for model trucks in 2D (for each subsystem there are 4 masses) with disturbances
%

% Copyright is with the following author(s):
%
% (C) 2013 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end

    load('modelTrucks2Dddist.mat')
    load('PnPestimatorsdist.mat')
    load('PnPestimatorsOutputsdist.mat')
    
    Tsim = 20;
    N    = Tsim/modelTrucks2Dddist.Ts;
    
    n    = size(modelTrucks2Dddist.getA,2);
    m    = size(modelTrucks2Dddist.getB,2);
    p    = size(modelTrucks2Dddist.getC,1);
    ni   = n/modelTrucks2Dddist.numSys;
    mi   = m/modelTrucks2Dddist.numSys;
    pi   = p/modelTrucks2Dddist.numSys;
    ind  = 1:modelTrucks2Dddist.numSys;
    
    u    = repmat(1e-1*sin((0:N-1)),m,1);
    x    = zeros(n,N+1) ;
    xest = zeros(n,N+1) ;
    xestO= zeros(n,N+1) ;
    y    = zeros(p,N);
    
    dist = modelTrucks2Dddist.Kd(1);
    w    = -dist+rand(modelTrucks2Dddist.numSys,N)*dist*2;
    
    options = sdpsettings('verbose',0);
    
    % choose a feasible random x0
    for i=1:modelTrucks2Dddist.numSys
        dir = -1+rand(ni,1)*2;
        [ ~, ~, xest((i-1)*ni+1:i*ni,1) ]  = PnPestimatorsdist(i).supportFunctionS(dir,options);
        [ ~, ~, xestO((i-1)*ni+1:i*ni,1) ] = PnPestimatorsOutputsdist(i).supportFunctionS(dir,options);
    end
    
    
    for t=1:N
        x(:,t+1) = modelTrucks2Dddist.getA*x(:,t) + modelTrucks2Dddist.getB*u(:,t) + modelTrucks2Dddist.getM*w(:,t);
        y(:,t)   = modelTrucks2Dddist.getC*x(:,t) ;
        
        for i=1:modelTrucks2Dddist.numSys
            xtj = [];
            ytj = [];
            for j=ind(modelTrucks2Dddist.couplingmatrix(i,:))
                if i==j
                    continue;
                end
                xtj = [ xtj ; xest((j-1)*ni+1:j*ni,t) ];
                ytj = [ ytj ; y((j-1)*pi+1:j*pi,t) ];
            end
            xest((i-1)*ni+1:i*ni,t+1)  = PnPestimatorsdist(i).computeEstimation( xest((i-1)*ni+1:i*ni,t)  , y((i-1)*pi+1:i*pi,t) , u((i-1)*mi+1:i*mi,t) , xtj );
            xestO((i-1)*ni+1:i*ni,t+1) = PnPestimatorsOutputsdist(i).computeEstimation( xestO((i-1)*ni+1:i*ni,t) , y((i-1)*pi+1:i*pi,t) , u((i-1)*mi+1:i*mi,t) , xtj , ytj );
        end
        
    end
    
    eest  = x-xest;
    eestO = x-xestO;
    
    fig1 = figure(1);
    axes1 = axes('Parent',fig1,'FontSize',22);
    Tx  = 30;
    Ts  = modelTrucks2Dddist.Ts;
    hold on
    box on
    plot(0:Ts:(Tx-1)*Ts,x(1:4,1:Tx)','--','LineWidth',1)
    plot(0:Ts:(Tx-1)*Ts,xest(1:4,1:Tx)','LineWidth',1)
    xlabel('t [s]','FontSize',22);
    ylabel('x_{[1,1:4]}','FontSize',22);
    
    fig2 = figure(2);
    axes2 = axes('Parent',fig2,'FontSize',22);
    hold on
    box on
    plot(0:Ts:(Tx-1)*Ts,x(1:4,1:Tx)','--','LineWidth',1)
    plot(0:Ts:(Tx-1)*Ts,xestO(1:4,1:Tx)','LineWidth',1)
    xlabel('t [s]','FontSize',22);
    ylabel('x_{[1,1:4]}','FontSize',22);
    
    fig3 = figure(3);
    axes3 = axes('Parent',fig3,'FontSize',22);
    ylim([-1.5 1.5]);
    hold on
    box on
    plot(0:Ts:N*Ts,eest','b','LineWidth',1)
    xlabel('t [s]','FontSize',22);
    ylabel('e','FontSize',22);
    
    fig4 = figure(4);
    axes4 = axes('Parent',fig4,'FontSize',22);
    ylim([-1.5 1.5]);
    hold on
    box on
    plot(0:Ts:N*Ts,eestO','b','LineWidth',1)
    xlabel('t [s]','FontSize',22);
    ylabel('e','FontSize',22);
    
    
    mkdir([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist'])
    saveas(fig1,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist1'],'fig')
    saveas(fig2,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist2'],'fig')
    saveas(fig3,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist3'],'fig')
    saveas(fig4,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist4'],'fig')
    saveas(fig1,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist1'],'epsc')
    saveas(fig2,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist2'],'epsc')
    saveas(fig3,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist3'],'epsc')
    saveas(fig4,[pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpEstimator/simulations_yesdist/dist4'],'epsc')
    
end