% EXAMPLEPNPCTRL example for testing pnpctrl objects
%

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

global pnpmpcToolboxGlobalOptions;
if ~isstruct(pnpmpcToolboxGlobalOptions),
    pnpmpc_toolbox_err;
end

clear

N = 10;

disp('########')
disp('First Example: m=10, h=0.5, k=0.5. Decentralized controller')
M = [ 10 10 ];
k = [ 0.5 0.5 ];
h = [ 0.5 0.5 ];
[ modelTrucks1Dc1, modelTrucks1Dd1 ] = makeModelTrucks1Dmkh(N,M,k,h);
try
    [ Trucks1Dpnpctrl1, K1 ]         = makePnpCtrlTrucks1D(modelTrucks1Dd1,0);
    disp('Eigenvalues of the closed-loop system')
    E1 = eig(full(modelTrucks1Dd1.getA+modelTrucks1Dd1.getB*K1))
catch e
    disp(e.message)
end

pause

disp('########')
disp('Second Example: m=0.01, h=0.5, k=0.5. Decentralized controller')
M = [ 0.01 0.01 ];
k = [ 0.5 0.5 ];
h = [ 0.5 0.5 ];
[ modelTrucks1Dc2, modelTrucks1Dd2 ] = makeModelTrucks1Dmkh(N,M,k,h);
try
    [ Trucks1Dpnpctrl2, K2 ]         = makePnpCtrlTrucks1D(modelTrucks1Dd2,0);
    disp('Eigenvalues of the closed-loop system')
    E2 = eig(full(modelTrucks1Dd2.getA+modelTrucks1Dd2.getB*K2))
catch e
    disp(e.message)
end

pause

disp('########')
disp('Third Example: m=0.01, h=0.5, k=0.5. Distributed controller')
modelTrucks1Dc3 = modelTrucks1Dc2;
modelTrucks1Dd3 = modelTrucks1Dd2;
try
    [ Trucks1Dpnpctrl3, K3 ]         = makePnpCtrlTrucks1D(modelTrucks1Dd3,1);
    disp('Eigenvalues of the closed-loop system')
    E3 = eig(full(modelTrucks1Dd3.getA+modelTrucks1Dd3.getB*K3))
catch e
    disp(e.message)
end