function [ modelTrucks1Dc, modelTrucks1Dd ] = makeModelTrucks1Dmkh(N,M,k,h)
% MAKEMODELTRUCKS1DMKH create model trucks in 1D with given min and max M, k, h
%

% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end
    
    minM          = M(1);
    maxM          = M(2);
    mink          = k(1);
    maxk          = k(2);
    minh          = h(1);
    maxh          = h(2);
    
    M = minM+rand(1,N)*(maxM-minM);
    k = mink+rand(1,N-1)*(maxk-mink);
    h = minh+rand(1,N-1)*(maxh-minh);
    
    % local dynamics for each truck and coupling terms among trucks
    modelTrucks1Dc = lss;
    modelTrucks1Dc = modelTrucks1Dc.addSystem ([0,1;-k(1)/M(1),-h(1)/M(1)],[0;100/M(1)]);
    for i=2:N-1
        modelTrucks1Dc = modelTrucks1Dc.addSystem   ([0,1;-(k(i-1)+k(i))/M(i),-(h(i-1)+h(i))/M(i)],[0;100/M(i)]);
        modelTrucks1Dc = modelTrucks1Dc.addCoupling (i-1,i,[0,0;k(i-1)/M(i-1),h(i-1)/M(i-1)],zeros(2,1));
        modelTrucks1Dc = modelTrucks1Dc.addCoupling (i,i-1,[0,0;k(i-1)/M(i),h(i-1)/M(i)],zeros(2,1));
    end
    modelTrucks1Dc = modelTrucks1Dc.addSystem   ([0,1;-k(N-1)/M(N),-h(N-1)/M(N)],[0;100/M(N)]);
    modelTrucks1Dc = modelTrucks1Dc.addCoupling (N,N-1,[0,0;k(N-1)/M(N),h(N-1)/M(N)],zeros(2,1));
    modelTrucks1Dc = modelTrucks1Dc.addCoupling (N-1,N,[0,0;k(N-1)/M(N-1),h(N-1)/M(N-1)],zeros(2,1));
    
    clear M k h
    
    modelTrucks1Dd = modelTrucks1Dc.clss2dlss(0.2,'subsystem');
    
end