function [ Trucks1Dpnp ] = makePnpmpcTrucks1D_disturbances_bounded(modelTrucks1Dd,options)
% MAKEPNPMPCTRUCKS1D_DISTURBANCES_BOUNDED create pnpmpc controllers for model trucks in 1D with bounded disturbances
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end 
    
    if nargin<2
        options = sdpsettings('verbose',0);
    end

    NMPC = 10;
    Q    = eye(modelTrucks1Dd.ni(1))*100;
    R    = eye(modelTrucks1Dd.mi(1))*1;

    for i=1:modelTrucks1Dd.numSys
        flag(i).ExoBounded = (i-1)*2+1:i*2;
    end
    
    tic
    Trucks1Dpnp = modelTrucks1Dd.createCtrlPnPMPC(NMPC,flag,options);
    time_pnp = toc;
    parfor i=1:modelTrucks1Dd.numSys
        Trucks1Dpnp(i) = Trucks1Dpnp(i).zeroTerminal(Q,R);
    end
    time_pnp_stability = toc;

    save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/pnpmpc/1D_disturbances_bounded/Trucks1Dpnp'],'Trucks1Dpnp','time_pnp_stability','time_pnp')

end