function [ x, u ] = runSimTrucks2D(Tsim,x0,modelTrucks2Dc,modelTrucks2Dd,Trucks2Dpnp,options)
% RUNSIMTRUCKS2D run a simulation for the trucks model in 2D using pnpmpc controllers with initial state x0
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Alberto Battocchio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, alberto.battocchio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end    

    if nargin<=5
        options = sdpsettings('verbose',0);
    end
    
    ni = 4;
    mi = 2;
    
    if verLessThan('matlab', '7.12')
        rand('seed');
    else
        rng('default');
    end
    
    xsim   = [];
    timeX  = [];
    usim   = [];
    
    for t=0:Tsim-1        
        
        fprintf('Running... Time: %d\n',t)
        
        uRH    = zeros(modelTrucks2Dd.numSys*mi,1);
        
        for i=1:modelTrucks2Dd.numSys
            uRH((i-1)*mi+1:i*mi,1) = Trucks2Dpnp(i).uRH(x0((i-1)*ni+1:i*ni,1),[],[],[],[],[],options);
        end
        
        x0ode = ode45(@(tt,x)simulatorTrucks(tt,x,uRH,[],modelTrucks2Dc),[0 modelTrucks2Dd.Ts],x0);
        x0    = x0ode.y(:,end);
        
        xsim   = [ xsim  ; x0ode.y(:,1:end-1)' ];
        timeX  = [ timeX ; t*modelTrucks2Dd.Ts + x0ode.x(1:end-1)' ];
        usim   = [ usim  ; uRH' ];
    end
    
    xsim                   = [ xsim  ; x0ode.y(:,end)' ];
    timeX                  = [ timeX ; t*modelTrucks2Dd.Ts + x0ode.x(end) ];
    
    u.signals.values       = usim;
    u.signals.dimensions   = size(usim,2);
    u.time                 = 0:modelTrucks2Dd.Ts:modelTrucks2Dd.Ts*(Tsim-1);
    
    x.signals.values       = xsim;
    x.signals.dimensions   = size(xsim,2);
    x.time                 = timeX;
    
    
    modelTrucks2Dc.plotX([],[],x);
    axis tight
    modelTrucks2Dc.stairsU([],[],u);
    axis tight
    
end