% MAKEPNSLSMODEL create an LSmodel object of power network systems of scenario 1
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

clear
close all

global pnpmpcToolboxGlobalOptions;
if ~isstruct(pnpmpcToolboxGlobalOptions),
    pnpmpc_toolbox_err;
end

H  = [12 10 8 8];
R  = [0.05 0.0625 0.08 0.08];
D  = [0.7 0.9 0.9 0.7];
Tt = [0.65 0.4 0.3 0.6];
Tg = [0.1 0.1 0.1 0.1];
P  = zeros(4);
P(1,2) = 4;
P(2,3) = 2;
P(3,4) = 2;
P = P+P';

DtetaMIN = [0.1 0.1 0.1 0.1];
DtetaMAX = [0.1 0.1 0.1 0.1];
DrefMIN  = [0.5 0.65 0.65 0.55];
DrefMAX  = [0.5 0.65 0.65 0.55];

link{1} = 2;
link{2} = [1,3];
link{3} = [2,4];
link{4} = 3;

namewex = {};
namezex = {};

%% Scenario 1
N = 4;

% add each area
for i = 1:N
    A   = [0                           1                  0             0    ;
           -sum(P(1:N,i))/(2*H(i))   -D(i)/(2*H(i))      1/(2*H(i))      0    ;
           0                            0                -1/Tt(i)      1/Tt(i);
           0                         -1/(R(i)*Tg(i))       0          -1/Tg(i)];
    namex = { strcat('delta',num2str(i))
              strcat('omega',num2str(i))
              strcat('Pm',num2str(i))
              strcat('Pv',num2str(i)) };
    B   = [0 0 0 1/Tg(i)]';
    L   = [0 -1/(2*H(i)) 0 0]';
    AIJ = zeros(4,length(link{i}));
    nameu = { strcat('Pref',num2str(i))
              strcat('PL',num2str(i)) };
    for k = 1:length(link{i})
        j = link{i}(k);
        AIJ(2,k) = P(i,j)/(2*H(i));
        nameu{length(nameu)+1} = strcat('delta',num2str(j));
    end
    
    B = [ B L AIJ ];
    
    SYS{i} = c2d(ss(A,B,eye(size(A)),zeros(size(A,2),size(B,2))),1);
    SYS{i}.InputName  = nameu;
    SYS{i}.StateName  = namex;
    SYS{i}.OutputName = namex;
    SYS{i}.Name = ['Area ', num2str(i)];
    
    namewex{length(namewex)+1} = nameu{1} ;
    namewex{length(namewex)+1} = nameu{2} ;
    namezex{length(namezex)+1} = namex{1} ;
    namezex{length(namezex)+1} = namex{2} ;
    namezex{length(namezex)+1} = namex{3} ;
    namezex{length(namezex)+1} = namex{4} ;
end

pnsD1ssLSmodel = LSmodel(SYS,0,namewex,namezex);

for i = 1:length(namewex)/2
    pnsD1ssLSmodel = pnsD1ssLSmodel.set_sig_lim(namewex((i-1)*2+1),-DrefMIN(i),DrefMAX(i));
end
for i = 1:length(namezex)/4
    pnsD1ssLSmodel = pnsD1ssLSmodel.set_sig_lim(namezex((i-1)*4+1),-DtetaMIN(i),DtetaMAX(i));
end

pnsD1ssLSmodel.plot

save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/wide_integration/pnsD1ssLSmodel'],'pnsD1ssLSmodel')