% MAKEPNPMPCCONTROLLERSPNS4LSMODEL create pnpmpc controllers for power network systems of scenario 1 described by an LSmodel object
%

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

clear
close all

global pnpmpcToolboxGlobalOptions;
if ~isstruct(pnpmpcToolboxGlobalOptions),
    pnpmpc_toolbox_err;
end

%% Scenario 1: pnpmpc controllers
load([pnpmpcToolboxGlobalOptions.pathInstalled  '/examples/wide_integration/pnsD1ssLSmodel'])

Q    = diag([500 0.01 0.01 10]);
R    = 10;
N    = 15;
kmin = [ 8 8 8 6 ];
kmax = [ 20 20 20 20 ];

% m and p array for lsmodel2lss
% the odd elements of m are the power references of each area, therefore
% they are the local inputs of each subsystem; the even elements of m are the
% power loads of each area, therefore they are the exogenous signals of
% each subsystem
m = [ 1 -1 2 -1 3 -1 4 -1 ];
% the elements of p are the outputs of each subsystem, therefore they are
% the states of each area
p = [ 1 1 1 1 2 2 2 2 3 3 3 3 4 4 4 4 ];

% convert LSmodel to lss 
objlss = lsmodel2lss(pnsD1ssLSmodel,m,p);
% design pnp controllers
for i =1:numel(kmin)
    flag(i).k = { kmin(i) kmax(i) };
end
ctrlPnpMpcFromLSmodel = objlss.createCtrlPnPMPC(N,flag,sdpsettings('verbose',0));
% one can also use the following instruction
% [ ctrlPnpMpcFromLSmodel objlss ] = createCtrlPnPMPC4lsmodel( pnsD1ssLSmodel , N , {kmin,kmax} , m , p , sdpsettings('verbose',0) )

% zero terminal constraint for each pnpmpc controller
ctrlPnpMpcZeroFromLSmodel = ctrlPnpMpcFromLSmodel;
for i=1:size(ctrlPnpMpcFromLSmodel,2)
    ctrlPnpMpcZeroFromLSmodel(i) = ctrlPnpMpcFromLSmodel(i).zeroTerminal(Q,R);
end

save([pnpmpcToolboxGlobalOptions.pathInstalled '/examples/wide_integration/ctrlPnpMpcZeroFromLSmodel'],'ctrlPnpMpcZeroFromLSmodel')