% EXAMPLE1OUTERAPPROXIMATION computes outer approximation of function f
%
% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

clear
close all

% definition of function f, set X and sampling of f(X)
npoints = 500;
X  = zonotope(zeros(2,1),[2 0;0 3]);
xf = zeros(X.Dim,npoints);
f  = @(x,w)([  1+0.1*x(1)+0.5*x(2)-exp(0.1*x(1)^2) ; 
    0.1+0.9*x(1)-0.1*x(2)-0.1*cos(x(2))+0.05*x(2)^2 ]);
for i=1:size(xf,2)
    xx = randpoint(X);
    xf(:,i) = f(xx);
end

% options for outerApproximation function
options.split.ngenerators = 2;
options.split.alpha = 0.5;
options.split.max_zono = 5;

% compute zonotope approximation of f(X)
% Zu approximation using 1 zonotope
% ZuVec approximation using options.split.max_zono zonotopes
% Xs zonotope X splitted
% J jacobian and H hessian are outputs variables for future computations
% The third and fourth input argument are empty, that means the user does
% not know convex functions gf and hf, such that f = gf - hf. Therefore the
% function outerApproximation computes gf and hf. We highlight that the 
% IntLab toolbox http://www.ti3.tuhh.de/rump/intlab/ is needed.
[ Zu, ZuVec, Xs, J, H ] = outerApproximation(X,f,[],[],[],options);

% plots
figh = figure(1);
subplot(1,2,2)
hold on
plotZ(Zu,'y')
plotZ(ZuVec,'r')
plot(xf(1,:),xf(2,:),'b.')
box on
subplot(1,2,1)
plotZ(Xs,'g')
box on