% EXAMPLE3OUTERAPPROXIMATION computes outer approximation of function f
% Differently from EXAMPLE1OUTERAPPROXIMATION we explicit the functions g and
% h such that f = g-h, g and h convex functions. Moreover we cannot split
% variable x(1)
%
% Copyright is with the following author(s):
%
% (C) 2014
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
% (C) 2012 
%     Stefano Riverso
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

clear
close all

% definition of function f, set X and sampling of f(X)
% differently from example2outerApproximation we want to split only along 
% x(1), therefore x(2) is substituted by w(1) 
npoints = 500;
X1 = zonotope(0,2);
W  = zonotope(0,3);
X  = X1*W;
xf = zeros(X.Dim,npoints);
f  = @(x,w)([  1+0.1*x(1)+0.5*w(1)-exp(0.1*x(1)^2)   ;    
    0.1+0.9*x(1)-0.1*w(1)-0.1*cos(w(1))+0.05*w(1)^2     ]);
for i=1:size(xf,2)
    xx = randpoint(X);
    xf(:,i) = f(xx(1),xx(2));
end

% definition of g and h such that f=g-h where g and h are convex functions
g  = @(x,w)([  0.5*w(1)   ;    0.1+0.9*x(1)-0.1*cos(w(1))+0.05*w(1)^2   ]);
h  = @(x,w)([  -1-0.1*x(1)+exp(0.1*x(1)^2)   ;    0.1*w(1)     ]);

% options for outerApproximation function
options.split.ngenerators = 2;
options.split.alpha = 0.5;
options.split.max_zono = 5;

% compute zonotope approximation of f(X)
% Zu approximation using 1 zonotope
% ZuVec approximation using options.split.max_zono zonotopes
% Xs zonotope X splitted
% J jacobian and H hessian are outputs variables for future computations
[ Zu, ZuVec, Xs, J, H ] = outerApproximation(X1,f,W,g,h,options);

% plots
h=figure(1);
subplot(1,2,2)
hold on
plotZ(Zu,'y')
plotZ(ZuVec,'r')
plot(xf(1,:),xf(2,:),'b.')
box on
subplot(1,2,1)
plotZ(Xs,'g')
box on