% EXAMPLE1 of zonotopeRCI class
%
%
% see also ZONOTOPERCI

% Copyright is with the following author(s):
%
% (C) 2012 
%     Stefano Riverso, Giuseppe Giorgio, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     stefano.riverso@unipv.it, giuseppe.giorgio01@universitadipavia.it,
%     giancarlo.ferrari@unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

global pnpmpcToolboxGlobalOptions;
if ~isstruct(pnpmpcToolboxGlobalOptions),
    pnpmpc_toolbox_err;
end

clear
close

% matrices of the LTI system
A  = [ 1 1 ; 0 1 ] ;
B  = [ 1 ; 1 ] ;

% matrices for constraints on state and input variables
% X = { x | cx*x<=dx }
% U = { u | cu*u<=du }
cx = [ 1 0 ; -1 0 ; 0 -1 ; 0 1 ; -1 -1 ];
dx = [ 1.85 3 3 3 2.2 ]';
cu = [ 1 ; -1 ];
du = [ 3 ; 3 ];

% parameter of the algorithm, greater than the number of states
k  = 5;

% matrices of the zonotope for the description of set W = { w=f+Ed ,
% |d|inf<=1 }
E  = [ 1 0 ; 0 1 ];
f  = [ 0   ; 0 ];

% create the zonotopic robust control invariant set
qa = 1 ; qb = 1 ; qp = 1 ;
Z  = zonotopeRCI(A,B,{cx,dx},{cu,du},{f,E},k,[qa,qb,qp],sdpsettings('verbose',0))

% in alternative, if one knows the polytope description of W as W = { w |
% cw*w<=dw } then it is possible to use the following instruction in order
% to reduce the computation of zonotopeRCI class
%
% cw = [ eye(2) ; -eye(2) ]; dw = ones(4,1);
% Z  = zonotopeRCI(A,B,{cx,dx},{cu,du},{f,E;cw,dw},k,[qa,qb,qp]);


% plot the zonotopic robust control invariant set
Z.plot