function mask = createMaskDec(vectn,vectm)
% CREATEMASKDEC Creates a block diagonal matrix of ones
% 
% mask = createMaskDec(vectn,vectm)
% ---------------------------------------------------------------------------
% DESCRIPTION
% ---------------------------------------------------------------------------  
% Create a diagonal block matrix of ones.
%  
% USAGE:
% mask = createMaskDec(vectn,vectm)
% mask = createMaskDec(vectn)          vectm is set to vectn
% 
% ---------------------------------------------------------------------------
% INPUT
% ---------------------------------------------------------------------------
% vectn = vector. vectn(i) is the number of rows of the i-th block of the matrix
% 
% vectm = vector. vectm(i) is the number of columns of the i-th block of the matrix
% 
% ---------------------------------------------------------------------------
% OUTPUT
% ---------------------------------------------------------------------------
% mask desired block diagonal matrix
% 
%
% see also GETAD GETAC GETBD GETBC GETCD GETCC GETDD GETDC

% Copyright is with the following author(s):
%
% (C) 2012 
%     Alberto Battocchio, Stefano Riverso, Giancarlo Ferrari Trecate
%     Identification and Control of Dynamic Systems Laboratory,
%     Universita' degli Studi di Pavia, Italy
%     alberto.battocchio01(at)universitadipavia.it, stefano.riverso(at)unipv.it, 
%     giancarlo.ferrari(at)unipv.it
%

% ---------------------------------------------------------------------------
% Legal note:
%          This program is free software; you can redistribute it and/or
%          modify it under the terms of the GNU General Public
%          License as published by the Free Software Foundation; either
%          version 2.1 of the License, or (at your option) any later version.
%
%          This program is distributed in the hope that it will be useful,
%          but WITHOUT ANY WARRANTY; without even the implied warranty of
%          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%          General Public License for more details.
% 
%          You should have received a copy of the GNU General Public
%          License along with this library; if not, write to the 
%          Free Software Foundation, Inc., 
%          59 Temple Place, Suite 330, 
%          Boston, MA  02111-1307  USA
%
% ---------------------------------------------------------------------------

    global pnpmpcToolboxGlobalOptions;
    if ~isstruct(pnpmpcToolboxGlobalOptions),
        pnpmpc_toolbox_err;
    end    

    if nargin~=1 && nargin~=2
        error('CREATEMASKDEC: number of parameters. see help CREATEMASKDEC')
    end
    
    if nargin==1
        vectm = vectn;
    end
    
    bn = length(vectn);    
    if bn~=length(vectm)
        error('CREATEMASKDEC: length of vectn and vectm must be equal')
    end
    
    sn = sum(vectn);
    sm = sum(vectm);
    
    mask = zeros(sn,sm);
    for i=1:bn
        mask(sum(vectn(1:i-1))+1:sum(vectn(1:i)),sum(vectm(1:i-1))+1:sum(vectm(1:i))) = ones(vectn(i),vectm(i));
    end
    
end